<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:hl7="urn:hl7-org:v3"
    exclude-result-prefixes="#all"
    version="2.0">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Sep 25, 2012</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket</xd:p>
            <xd:p></xd:p>
        </xd:desc>
    </xd:doc>
    
    <xsl:output indent="yes"/>
    <xsl:param name="cdar3xsd" select="'cdar3schemas/multicacheschemas/CDA.xsd'"/>
    
    <!-- CDAr2 contents -->
    <xsl:param name="cdar2pocdXsd" select="'cdar2schemas/schemas/POCD_MT000040.xsd'"/>
    <!-- CDAr3 contents -->
    <xsl:param name="cdar3pocdXsd" select="'cdar3schemas/multicacheschemas/POCD_MT000040UV.xsd'"/>
    <!-- CDAr3 Clinical Statements -->
    <xsl:param name="cdar3csXsd" select="'cdar3schemas/multicacheschemas/COCT_MT980000UV.xsd'"/>
    <!-- CDAr3 Participants -->
    <xsl:param name="cdar3partXsd" select="'cdar3schemas/multicacheschemas/COCT_MT990000UV.xsd'"/>
    
    <xsl:variable name="infrastructureRoot" as="xs:string*" select="('realmCode','typeId','templateId')"/>
    <xsl:variable name="mappingTable">
        <!--wrap>
            <xsl:for-each select="document($cdar2pocdXsd)//xs:complexType">
                <map cdar2="{@name}" cdar3="{replace(@name,'POCD_MT000040.','POCD_MT000040UV.')}"/>
            </xsl:for-each>
        </wrap-->
        <wrap>
            <!-- Header (and maybe body too) -->
            <map cdar2="POCD_MT000040.InfrastructureRoot.typeId" cdar3="POCD_MT000040UV.InfrastructureRoot.typeId"/>
            <map cdar2="POCD_MT000040.InfrastructureRoot.templateId" cdar3="POCD_MT000040UV.InfrastructureRoot.templateId"/>
            <map cdar2="POCD_MT000040.AssignedAuthor" cdar3="POCD_MT000040UV.AssignedAuthor"/>
            <map cdar2="POCD_MT000040.AssignedCustodian" cdar3="POCD_MT000040UV.AssignedCustodian"/>
            <map cdar2="POCD_MT000040.AssignedEntity" cdar3="POCD_MT000040UV.AssignedEntity"/>
            <map cdar2="POCD_MT000040.AssociatedEntity" cdar3="POCD_MT000040UV.AssociatedEntity"/>
            <map cdar2="POCD_MT000040.Authenticator" cdar3="POCD_MT000040UV.Authenticator"/>
            <map cdar2="POCD_MT000040.Author" cdar3="POCD_MT000040UV.Author"/>
            <map cdar2="POCD_MT000040.AuthoringDevice" cdar3="POCD_MT000040UV.Device"/>
            <map cdar2="POCD_MT000040.Authorization" cdar3="POCD_MT000040UV.Authorization"/>
            <map cdar2="POCD_MT000040.Birthplace" cdar3="POCD_MT000040UV.Birthplace"/>
            <map cdar2="POCD_MT000040.ClinicalDocument" cdar3="POCD_MT000040UV.ClinicalDocument"/>
            <map cdar2="POCD_MT000040.Component1" cdar3="POCD_MT000040UV.Component1"/>
            <map cdar2="POCD_MT000040.Component2" cdar3="POCD_MT000040UV.Component2"/>
            <map cdar2="POCD_MT000040.Component3" cdar3="POCD_MT000040UV.Component3"/>
            <map cdar2="POCD_MT000040.Component5" cdar3="POCD_MT000040UV.Component5"/>
            <map cdar2="POCD_MT000040.Consent" cdar3="POCD_MT000040UV.Consent"/>
            <map cdar2="POCD_MT000040.Custodian" cdar3="POCD_MT000040UV.Custodian"/>
            <map cdar2="POCD_MT000040.CustodianOrganization" cdar3="POCD_MT000040UV.CustodianOrganization"/>
            <map cdar2="POCD_MT000040.DataEnterer" cdar3="POCD_MT000040UV.DataEnterer"/>
            <map cdar2="POCD_MT000040.DocumentationOf" cdar3="POCD_MT000040UV.DocumentationOf"/>
            <map cdar2="POCD_MT000040.EncompassingEncounter" cdar3="POCD_MT000040UV.EncompassingEncounter"/>
            <map cdar2="POCD_MT000040.EncounterParticipant" cdar3="POCD_MT000040UV.EncounterParticipant"/>
            <map cdar2="POCD_MT000040.Entry" cdar3="POCD_MT000040UV.Entry"/>
            <map cdar2="POCD_MT000040.Guardian" cdar3="POCD_MT000040UV.Guardian"/>
            <map cdar2="POCD_MT000040.HealthCareFacility" cdar3="POCD_MT000040UV.HealthCareFacility"/>
            <map cdar2="POCD_MT000040.Informant12" cdar3="POCD_MT000040UV.Informant"/>
            <map cdar2="POCD_MT000040.InformationRecipient" cdar3="POCD_MT000040UV.InformationRecipient"/>
            <map cdar2="POCD_MT000040.InFulfillmentOf" cdar3="POCD_MT000040UV.InFulfillmentOf"/>
            <map cdar2="POCD_MT000040.IntendedRecipient" cdar3="POCD_MT000040UV.IntendedRecipient"/>
            <map cdar2="POCD_MT000040.LanguageCommunication" cdar3="POCD_MT000040UV.LanguageCommunication"/>
            <map cdar2="POCD_MT000040.LegalAuthenticator" cdar3="POCD_MT000040UV.LegalAuthenticator"/>
            <map cdar2="POCD_MT000040.Location" cdar3="POCD_MT000040UV.Location"/>
            <map cdar2="POCD_MT000040.MaintainedEntity" cdar3="POCD_MT000040UV.MaintainedEntity"/>
            <map cdar2="POCD_MT000040.NonXMLBody" cdar3="POCD_MT000040UV.NonStructuredBody"/>
            <map cdar2="POCD_MT000040.Order" cdar3="POCD_MT000040UV.Order"/>
            <map cdar2="POCD_MT000040.Organization" cdar3="POCD_MT000040UV.Organization"/>
            <map cdar2="POCD_MT000040.OrganizationPartOf" cdar3="POCD_MT000040UV.OrganizationPartOf"/>
            <map cdar2="POCD_MT000040.ParentDocument" cdar3="POCD_MT000040UV.ParentDocument"/>
            <map cdar2="POCD_MT000040.Participant1" cdar3="POCD_MT000040UV.Participant1"/>
            <map cdar2="POCD_MT000040.Patient" cdar3="POCD_MT000040UV.Patient"/>
            <map cdar2="POCD_MT000040.PatientRole" cdar3="POCD_MT000040UV.PatientRole"/>
            <map cdar2="POCD_MT000040.Performer1" cdar3="POCD_MT000040UV.Performer1"/>
            <map cdar2="POCD_MT000040.Person" cdar3="POCD_MT000040UV.Person"/>
            <map cdar2="POCD_MT000040.Place" cdar3="POCD_MT000040UV.Place"/>
            <map cdar2="POCD_MT000040.RecordTarget" cdar3="POCD_MT000040UV.RecordTarget"/>
            <map cdar2="POCD_MT000040.RelatedDocument" cdar3="POCD_MT000040UV.RelatedDocument"/>
            <map cdar2="POCD_MT000040.RelatedEntity" cdar3="POCD_MT000040UV.RelatedEntity"/>
            <map cdar2="POCD_MT000040.RelatedSubject" cdar3="POCD_MT000040UV.RelatedSubject"/>
            <map cdar2="POCD_MT000040.ResponsibleParty" cdar3="POCD_MT000040UV.ResponsibleParty"/>
            <map cdar2="POCD_MT000040.Section" cdar3="POCD_MT000040UV.Section"/>
            <map cdar2="POCD_MT000040.ServiceEvent" cdar3="POCD_MT000040UV.ServiceEvent"/>
            <map cdar2="POCD_MT000040.StructuredBody" cdar3="POCD_MT000040UV.StructuredBody"/>
            <map cdar2="POCD_MT000040.Subject" cdar3="POCD_MT000040UV.Subject"/>
            <map cdar2="POCD_MT000040.SubjectPerson" cdar3="POCD_MT000040UV.SubjectPerson"/>
            
            <!-- Entry Clinical Statement choice box with actrelationships and connected acts -->
            <map cdar2="POCD_MT000040.Act" cdar3="COCT_MT980000UV.Act"/>
            <map cdar2="POCD_MT000040.Component4" cdar3="COCT_MT980000UV.SourceOf"/>
            <map cdar2="POCD_MT000040.Consumable" cdar3="COCT_MT980000UV.Participant"/>
            <map cdar2="POCD_MT000040.Criterion" cdar3="COCT_MT980000UV.Observation"/>
            <map cdar2="POCD_MT000040.Encounter" cdar3="COCT_MT980000UV.Encounter"/>
            <map cdar2="POCD_MT000040.Device" cdar3="COCT_MT990000UV.Device"/>
            <map cdar2="POCD_MT000040.Entity" cdar3="COCT_MT990000UV.Entity"/>
            <map cdar2="POCD_MT000040.EntryRelationship" cdar3="COCT_MT980000UV.SourceOf"/>
            <map cdar2="POCD_MT000040.ExternalAct" cdar3="COCT_MT980000UV.Act"/>
            <map cdar2="POCD_MT000040.ExternalDocument" cdar3="COCT_MT980000UV.Document"/>
            <map cdar2="POCD_MT000040.ExternalObservation" cdar3="COCT_MT980000UV.Observation"/>
            <map cdar2="POCD_MT000040.ExternalProcedure" cdar3="COCT_MT980000UV.Procedure"/>
            <map cdar2="POCD_MT000040.LabeledDrug" cdar3="COCT_MT990000UV.ManufacturedMaterial"/>
            <map cdar2="POCD_MT000040.ManufacturedProduct" cdar3="COCT_MT990000UV.Role"/>
            <map cdar2="POCD_MT000040.Material" cdar3="COCT_MT990000UV.ManufacturedMaterial"/>
            <map cdar2="POCD_MT000040.Organizer" cdar3="COCT_MT980000UV.Observation"/>
            <map cdar2="POCD_MT000040.Observation" cdar3="COCT_MT980000UV.Observation"/>
            <map cdar2="POCD_MT000040.ObservationMedia" cdar3="COCT_MT980000UV.ObservationMedia"/>
            <map cdar2="POCD_MT000040.ObservationRange" cdar3="COCT_MT980000UV.Observation"/>
            <map cdar2="POCD_MT000040.Participant2" cdar3="COCT_MT980000UV.Participant"/>
            <map cdar2="POCD_MT000040.ParticipantRole" cdar3="COCT_MT990000UV.Role"/>
            <map cdar2="POCD_MT000040.Performer2" cdar3="COCT_MT980000UV.Participant"/>
            <map cdar2="POCD_MT000040.PlayingEntity" cdar3="COCT_MT990000UV.Entity"/>
            <map cdar2="POCD_MT000040.Precondition" cdar3="COCT_MT980000UV.SourceOf"/>
            <map cdar2="POCD_MT000040.Procedure" cdar3="COCT_MT980000UV.Procedure"/>
            <map cdar2="POCD_MT000040.Product" cdar3="COCT_MT980000UV.Participant"/>
            <map cdar2="POCD_MT000040.Reference" cdar3="COCT_MT980000UV.SourceOf"/>
            <map cdar2="POCD_MT000040.ReferenceRange" cdar3="COCT_MT980000UV.SourceOf"/>
            <map cdar2="POCD_MT000040.RegionOfInterest" cdar3="COCT_MT980000UV.RegionOfInterest"/>
            <map cdar2="POCD_MT000040.Specimen" cdar3="COCT_MT980000UV.Participant"/>
            <map cdar2="POCD_MT000040.SpecimenRole" cdar3="COCT_MT990000UV.Role"/><!-- ? -->
            <map cdar2="POCD_MT000040.SubstanceAdministration" cdar3="COCT_MT980000UV.SubstanceAdministration"/>
            <map cdar2="POCD_MT000040.Supply" cdar3="COCT_MT980000UV.Supply"/>
            
            <!-- Entry Clinical Statement choice box with participations and connected roles/entities -->
            
            <map cdar2="POCD_MT000040.RegionOfInterest.value" cdar3="POCD_MT000040UV.RegionOfInterest.value"/><!-- ? -->
            
        </wrap>
    </xsl:variable>
    
    <xsl:template match="/">
        <xsl:result-document href="cda2_to_cdar3.xsl" indent="yes">
            <xsl:comment>
    cda2_to_cdar3.xsl
    Copyright (C) 2012 Alexander-Henket
    
    This program is free software; you can redistribute it and/or modify it under the terms 
    of the GNU General Public License as published by the Free Software Foundation; 
    either version 3 of the License, or (at your option) any later version.
    
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
    without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.
    
    See http://www.gnu.org/licenses/gpl.html
</xsl:comment>
            <xsl:text>&#10;</xsl:text>
            <xsl:element name="xsl:stylesheet" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
                <xsl:namespace name="xs" select="'http://www.w3.org/2001/XMLSchema'"/>
                <xsl:namespace name="xsi" select="'http://www.w3.org/2001/XMLSchema-instance'"/>
                <xsl:namespace name="xd" select="'http://www.oxygenxml.com/ns/doc/xsl'"/>
                <xsl:namespace name="hl7" select="'urn:hl7-org:v3'"/>
                <xsl:attribute name="exclude-result-prefixes" select="'xs xsi xd hl7 xsl'"/>
                <xsl:attribute name="version" select="'2.0'"/>
                <xd:doc scope="stylesheet">
                    <xd:desc>
                        <xd:p><xd:b>Created on:</xd:b> <xsl:value-of select="format-dateTime(current-dateTime(),'[MNn] [D], [Y]', 'en', (), ())"/></xd:p>
                        <xd:p><xd:b>Author:</xd:b> Alexander Henket, E.Novation</xd:p>
                        <xd:p><xd:b>Email:</xd:b> alexander.henket(a)enovation.nl</xd:p>
                        <xd:p>Maps any CDA release 2 to CDA release 3 based on September 2012 Ballot, picks up any contents in other namespaces, 
                            and places that content to the end of the element if was found in. It is not possible to keep elements from other namespaces in between hl7 elements.</xd:p>
                        <xd:p>Maps all datatypes that are explicitly present in the CDAr2 specification. It may not map datatypes you explicitly declare in your instance, e.g. PPD_TS. 
                            Supported dtatypes are: 'AD','BL','BN','CD','CE','CO','CV','ED','EIVL_TS','EN','II','INT','IVL_INT','IVL_MO','IVL_PQ','IVL_REAL','IVL_TS','MO','ON',
                            'PIVL_TS','PN','PQ','REAL','RTO_PQ_PQ','SC','ST','TEL','TS'. In the event an unknown datatype is encountered, the XSL gives a message and terminates.</xd:p>
                        <xd:p><xd:b>NOTE:</xd:b> in datatypes R1 there used to be a qualifier element to coded elements. This no longer exists in datatypes R2. Hence this element is left
                        out of the output. Instead a comment will be add to the output stating what was omitted leading to data loss. Example: 
                            <xd:pre> Could not map qualifier for: name/code="12313" name/codeSystem="1.34" name/displayName="3453" value/code="23123" value/codeSystem="1.2.3" value/displayName="dsf" </xd:pre></xd:p>
                        <xd:p>See http://vimeo.com/16813271 for a video by Grahame Grieve on what changed in datatypes R2.</xd:p>
                        <xd:p>CDAr2 was not completely moved over to CDAr3 as it currently stands. In the context of where data would/will not be mapped you'll find a comment that 
                            starts with 'Skipping mapping of'. Currently skipped elements include: 'POCD_MT000040.AuthoringDevice.asMaintainedEntity', 'POCD_MT000040.ClinicalDocument.copyTime',
                            'POCD_MT000040.MaintainedEntity.effectiveTime', 'POCD_MT000040.MaintainedEntity.maintainingPerson' and 'POCD_MT000040UV.Patient.id'</xd:p>
                    </xd:desc>
                </xd:doc>
                
                <xsl:element name="xsl:output">
                    <xsl:attribute name="indent" select="'yes'"/>
                </xsl:element>
                
                <xsl:element name="xsl:variable">
                    <xsl:attribute name="name" select="'postalMapping'"/>
                    
                    <wrap>
                        <map cdar2="additionalLocator" cdar3="ADL"/>
                        <map cdar2="unitID" cdar3="UNID"/>
                        <map cdar2="unitType" cdar3="UNIT"/>
                        <map cdar2="deliveryAddressLine" cdar3="DAL"/>
                        <map cdar2="deliveryInstallationType" cdar3="DINST"/>
                        <map cdar2="deliveryInstallationArea" cdar3="DINSTA"/>
                        <map cdar2="deliveryInstallationQualifier" cdar3="DINSTQ"/>
                        <map cdar2="deliveryMode" cdar3="DMOD"/>
                        <map cdar2="deliveryModeIdentifier" cdar3="DMODID"/>
                        <map cdar2="streetAddressLine" cdar3="SAL"/>
                        <map cdar2="houseNumber" cdar3="BNR"/>
                        <map cdar2="houseNumberNumeric" cdar3="BNN"/>
                        <map cdar2="buildingNumberSuffix" cdar3="BNS"/>
                        <map cdar2="streetName" cdar3="STR"/>
                        <map cdar2="streetNameBase" cdar3="STB"/>
                        <map cdar2="streetNameType" cdar3="STTYP"/>
                        <map cdar2="direction" cdar3="DIR"/>
                        <map cdar2="careOf" cdar3="CAR"/>
                        <map cdar2="censusTract" cdar3="CEN"/>
                        <map cdar2="country" cdar3="CNT"/>
                        <map cdar2="county" cdar3="CPA"/>
                        <map cdar2="city" cdar3="CTY"/>
                        <map cdar2="delimiter" cdar3="DEL"/>
                        <map cdar2="postBox" cdar3="POB"/>
                        <map cdar2="precinct" cdar3="PRE"/>
                        <map cdar2="state" cdar3="STA"/>
                        <map cdar2="postalCode" cdar3="ZIP"/>
                    </wrap>
                </xsl:element>
                
                <xsl:element name="xsl:template">
                    <xsl:attribute name="match" select="'/'"/>
                    
                    <xsl:element name="xsl:apply-templates">
                        <xsl:attribute name="select" select="'hl7:ClinicalDocument'"/>
                    </xsl:element>
                </xsl:element>
                
                <xsl:element name="xsl:template">
                    <xsl:attribute name="match" select="'hl7:ClinicalDocument'"/>
                    
                    <xsl:element name="xsl:copy">
                        <xsl:element name="xsl:copy-of">
                            <xsl:attribute name="select" select="'@*'"/>
                        </xsl:element>
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:schemaLocation'"/>
                            <xsl:attribute name="select"><xsl:text>'urn:hl7-org:v3 cdar3schemas/multicacheschemas/CDA.xsd'</xsl:text></xsl:attribute>
                        </xsl:element>
                        
                        <xsl:element name="xsl:apply-templates">
                            <xsl:attribute name="select" select="'self::*'"/>
                            <xsl:attribute name="mode" select="'POCD_MT000040.ClinicalDocument'"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
                
                <xsl:apply-templates select="document($cdar2pocdXsd)//xs:complexType[not(starts-with(@name,'POCD_MT000040.InfrastructureRoot.'))]"/>
                
                <xsl:call-template name="infrastructureRootElements"/>
                
                <xsl:call-template name="datatypeConversions"/>
                
                <xsl:call-template name="fallbackConversions"/>
            </xsl:element>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="xs:complexType">
        <xsl:variable name="nm" select="@name"/>
        <xsl:variable name="nmuv" select="$mappingTable//map[@cdar2=$nm]/@cdar3"/>
        <xsl:variable name="ctr3">
            <xsl:choose>
                <xsl:when test="starts-with($nmuv,'POCD_MT000040UV.')">
                    <xsl:copy-of select="document($cdar3pocdXsd)//xs:complexType[@name=$nmuv]"/>
                </xsl:when>
                <xsl:when test="starts-with($nmuv,'COCT_MT980000UV.')">
                    <xsl:copy-of select="document($cdar3csXsd)//xs:complexType[@name=$nmuv]"/>
                </xsl:when>
                <xsl:when test="starts-with($nmuv,'COCT_MT990000UV.')">
                    <xsl:copy-of select="document($cdar3partXsd)//xs:complexType[@name=$nmuv]"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:message>Cannot map complexType '<xsl:value-of select="$nm"/>' to '<xsl:value-of select="$nmuv"/>'. Unknown source file.</xsl:message>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="clinicalStatement" as="xs:string*" select="('POCD_MT000040.Act','POCD_MT000040.Encounter','POCD_MT000040.Organizer','POCD_MT000040.Observation','POCD_MT000040.ObservationMedia','POCD_MT000040.Procedure','POCD_MT000040.RegionOfInterest','POCD_MT000040.SubstanceAdministration','POCD_MT000040.Supply')"/>
        
        <xsl:comment> <xsl:value-of select="@name"/> </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="match" select="'*'"/>
            <xsl:attribute name="mode" select="@name"/>
            
            <xsl:variable name="elementNameMap">
                <wrap>
                    <map cdar2="POCD_MT000040.AssignedAuthor.assignedAuthoringDevice" cdar3="assignedDevice"/>
                    <map cdar2="POCD_MT000040.Birthplace.place" cdar3="birthplace"/>
                    <map cdar2="POCD_MT000040.ClinicalDocument.participant" cdar3="participation1"/>
                    <map cdar2="POCD_MT000040.Component2.nonXMLBody" cdar3="nonStructuredBody"/>
                    <map cdar2="POCD_MT000040.Component4.organizer" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.Consumable.manufacturedProduct" cdar3="role"/>
                    <map cdar2="POCD_MT000040.Entry.organizer" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.EntryRelationship.organizer" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.Organizer.component" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Act.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Act.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Act.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Act.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Encounter.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Encounter.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Encounter.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Encounter.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.HealthCareFacility.location" cdar3="playingPlace"/>
                    <map cdar2="POCD_MT000040.HealthCareFacility.serviceProviderOrganization" cdar3="scopingOrganization"/>
                    <map cdar2="POCD_MT000040.ManufacturedProduct.manufacturedLabeledDrug" cdar3="playingManufacturedMaterial"/>
                    <map cdar2="POCD_MT000040.ManufacturedProduct.manufacturedMaterial" cdar3="playingManufacturedMaterial"/>
                    <map cdar2="POCD_MT000040.ManufacturedProduct.manufacturerOrganization" cdar3="scopingOrganization"/>
                    <map cdar2="POCD_MT000040.Organizer.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Organizer.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Organizer.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Organizer.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Observation.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Observation.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Observation.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Observation.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Observation.referenceRange" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.ObservationMedia.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Participant2.participantRole" cdar3="role"/>
                    <map cdar2="POCD_MT000040.Performer2.assignedEntity" cdar3="role"/>
                    <map cdar2="POCD_MT000040.Precondition.criterion" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.Procedure.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Procedure.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Procedure.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Procedure.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Product.manufacturedProduct" cdar3="role"/>
                    <map cdar2="POCD_MT000040.Reference.externalAct" cdar3="act"/>
                    <map cdar2="POCD_MT000040.Reference.externalDocument" cdar3="document"/>
                    <map cdar2="POCD_MT000040.Reference.externalObservation" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.Reference.externalProcedure" cdar3="procedure"/>
                    <map cdar2="POCD_MT000040.ReferenceRange.observationRange" cdar3="observation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.RegionOfInterest.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Specimen.specimenRole" cdar3="role"/>
                    <map cdar2="POCD_MT000040.SpecimenRole.specimenPlayingEntity" cdar3="playingEntity"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.consumable" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.SubstanceAdministration.reference" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Supply.entryRelationship" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Supply.author" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.informant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.participant" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.performer" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.subject" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.precondition" cdar3="outboundRelationship"/>
                    <map cdar2="POCD_MT000040.Supply.product" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.specimen" cdar3="participation"/>
                    <map cdar2="POCD_MT000040.Supply.reference" cdar3="outboundRelationship"/>
                </wrap>
            </xsl:variable>
            
            <xsl:for-each select=".//xs:element">
                <xsl:variable name="cdar2name" select="@name"/>
                <xsl:variable name="cdar3name" select="if ($elementNameMap//map[@cdar2=concat($nm,'.',$cdar2name)]) then ($elementNameMap//map[@cdar2=concat($nm,'.',$cdar2name)]/@cdar3) else ($cdar2name)"/>
                <xsl:variable name="ctsub" select="@type"/>
                <xsl:variable name="isComplex" select="starts-with($ctsub,'POCD_MT000040.')"/>
                
                <xsl:choose>
                    <xsl:when test="$ctr3//xs:element[@name=$cdar3name] or count(index-of($infrastructureRoot,$cdar2name))&gt;0">
                        <xsl:variable name="ctr3sub" select="$ctr3//xs:element[@name=$cdar2name]/@type"/>
                        <xsl:choose>
                            <!-- <xs:element name="typeId" type="POCD_MT000040.InfrastructureRoot.typeId"  minOccurs="0"/>
                         <xs:element name="templateId" type="POCD_MT000040.InfrastructureRoot.templateId"  minOccurs="0" maxOccurs="unbounded"/> -->
                            <xsl:when test="$cdar2name='realmCode'"/>
                            <xsl:when test="$ctsub='POCD_MT000040.InfrastructureRoot.typeId'"/>
                            <xsl:when test="$ctsub='POCD_MT000040.InfrastructureRoot.templateId'"/>
                            <xsl:when test="$nm='POCD_MT000040.ClinicalDocument' and $cdar2name='componentOf'"/>
                            <xsl:when test="$nm='POCD_MT000040.Organizer' and $cdar2name='effectiveTime'">
                                <xsl:element name="xsl:call-template">
                                    <xsl:attribute name="name" select="concat('dt-',$ctsub,'-to-QSET_TS')"/>
                                    
                                    <xsl:element name="xsl:with-param">
                                        <xsl:attribute name="name" select="'in'"/>
                                        <xsl:attribute name="select" select="concat('hl7:',$cdar2name)"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:when>
                            <!-- informant.time and author.time map differently under entry than the other occurences -->
                            <xsl:when test="($nm='POCD_MT000040.Author' and $cdar2name='time') or ($nm='POCD_MT000040.Informant12' and $cdar2name='time')">
                                <xsl:element name="xsl:choose">
                                    <xsl:element name="xsl:when">
                                        <xsl:attribute name="test" select="'ancestor::hl7:entry'"/>

                                        <xsl:element name="xsl:call-template">
                                            <xsl:attribute name="name" select="concat('dt-',$ctsub,'-to-IVL_TS')"/>

                                            <xsl:element name="xsl:with-param">
                                                <xsl:attribute name="name" select="'in'"/>
                                                <xsl:attribute name="select" select="concat('hl7:',$cdar2name)"/>
                                            </xsl:element>
                                        </xsl:element>
                                    </xsl:element>
                                    <xsl:element name="xsl:otherwise">
                                        
                                        <xsl:element name="xsl:call-template">
                                            <xsl:attribute name="name" select="concat('dt-',$ctsub,'-to-',$ctr3sub)"/>
                                            
                                            <xsl:element name="xsl:with-param">
                                                <xsl:attribute name="name" select="'in'"/>
                                                <xsl:attribute name="select" select="concat('hl7:',$cdar2name)"/>
                                            </xsl:element>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:when>
                            <!-- <xs:element name="subject" type="POCD_MT000040.Subject"  minOccurs="0"/> -->
                            <xsl:when test="$isComplex">
                                <!-- patch for moved attribute -->
                                <xsl:if test="$nm='POCD_MT000040.AssignedCustodian'">
                                    <xsl:element name="xsl:call-template">
                                        <xsl:attribute name="name" select="'dt-II-to-DSET_II'"/>
                                        
                                        <xsl:element name="xsl:with-param">
                                            <xsl:attribute name="name" select="'in'"/>
                                            <xsl:attribute name="select" select="'hl7:representedCustodianOrganization/hl7:id'"/>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:if>
                                
                                <xsl:element name="xsl:for-each">
                                    <xsl:attribute name="select" select="concat('hl7:',$cdar2name)"/>

                                    <xsl:element name="xsl:element">
                                        <xsl:attribute name="name">
                                            <xsl:choose>
                                                <xsl:when test="$ctsub='POCD_MT000040.Organizer'">
                                                    <xsl:text>{if (@classCode='CLUSTER') then ('composition') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.Author' and $cdar2name='assignedAuthor'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('role') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.AssignedAuthor' and $cdar2name='assignedPerson'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('playingPerson') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.AssignedAuthor' and $cdar2name='assignedAuthoringDevice'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('playingDevice') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.AssignedAuthor' and $cdar2name='representedOrganization'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('scopingOrganization') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.AssignedEntity' and $cdar2name='assignedPerson'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('playingPerson') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.AssignedEntity' and $cdar2name='representedOrganization'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('scopingOrganization') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.Informant12' and $cdar2name='assignedEntity'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('role') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.Informant12' and $cdar2name='relatedEntity'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('role') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.Subject' and $cdar2name='relatedSubject'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('role') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.RelatedSubject' and $cdar2name='subject'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('playingPerson') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:when test="$nm='POCD_MT000040.RelatedEntity' and $cdar2name='relatedPerson'">
                                                    <xsl:text>{if (ancestor::hl7:entry) then ('playingPerson') else ('</xsl:text><xsl:value-of select="$cdar3name"/><xsl:text>')}</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="$cdar3name"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:attribute>
                                        <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                                        
                                        <!-- Start of attributes -->
                                        <xsl:call-template name="handleSpecificAttributes">
                                            <xsl:with-param name="in" select="concat($nm,'.',$cdar2name)"/>
                                        </xsl:call-template>
                                        <xsl:element name="xsl:copy-of">
                                            <xsl:attribute name="select" select="'@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd'"/>
                                        </xsl:element>
                                        <xsl:element name="xsl:if">
                                            <xsl:attribute name="test" select="'self::node()[@negationInd]'"/>
                                            
                                            <xsl:element name="xsl:attribute">
                                                <xsl:attribute name="name" select="'actionNegationInd'"/>
                                                <xsl:attribute name="select" select="'@negationInd'"/>
                                            </xsl:element>
                                        </xsl:element>
                                        <xsl:if test="$cdar2name='organizer'">
                                            <xsl:element name="xsl:if">
                                                <xsl:attribute name="test">
                                                    <xsl:text>@classCode='CLUSTER'</xsl:text>
                                                </xsl:attribute>

                                                <xsl:element name="xsl:attribute">
                                                    <xsl:attribute name="name" select="'classCode'"/>
                                                    <xsl:attribute name="select">
                                                        <xsl:text>'COMPOSITION'</xsl:text>
                                                    </xsl:attribute>
                                                </xsl:element>
                                            </xsl:element>
                                        </xsl:if>
                                        <!-- End of attributes -->
                                        
                                        <xsl:element name="xsl:call-template">
                                            <xsl:attribute name="name" select="'infrastructureRootElements'"/>
                                        </xsl:element>
                                        
                                        <!-- Do ActRelationship stuff -->
                                        <xsl:call-template name="handleSpecificElements">
                                            <xsl:with-param name="in" select="concat($nm,'.',$cdar2name)"/>
                                        </xsl:call-template>
                                        
                                        <xsl:element name="xsl:apply-templates">
                                            <xsl:attribute name="select" select="'self::*'"/>
                                            <xsl:attribute name="mode" select="$ctsub"/>
                                        </xsl:element>
                                        <!-- End of elements -->
                                    </xsl:element>
                                </xsl:element>
                                
                                <!-- Filthy hack ... somehow in CDAr3 the component and componentOf are switched, so wait until we have component, and then append componentOf -->
                                <xsl:if test="$nm='POCD_MT000040.ClinicalDocument' and $cdar2name='component'">
                                    <xsl:variable name="hcdar2name" select="'componentOf'"/>
                                    <xsl:variable name="hcdar3name" select="if ($elementNameMap//map[@cdar2=concat($nm,'.',$hcdar2name)]) then ($elementNameMap//map[@cdar2=concat($nm,'.',$hcdar2name)]/@cdar3) else ($hcdar2name)"/>
                                    <xsl:variable name="hctsub" select="'POCD_MT000040.Component1'"/>
                                    
                                    <xsl:element name="xsl:for-each">
                                        <xsl:attribute name="select" select="concat('hl7:',$hcdar2name)"/>
                                        
                                        <xsl:element name="xsl:element">
                                            <xsl:attribute name="name" select="$hcdar3name"/>
                                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                                            
                                            <!-- Start of attributes -->
                                            <xsl:call-template name="handleSpecificAttributes">
                                                <xsl:with-param name="in" select="concat($nm,'.',$hcdar2name)"/>
                                            </xsl:call-template>
                                            <xsl:element name="xsl:copy-of">
                                                <xsl:attribute name="select" select="'@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd'"/>
                                            </xsl:element>
                                            <xsl:element name="xsl:if">
                                                <xsl:attribute name="test" select="'self::node()[@negationInd]'"/>
                                                
                                                <xsl:element name="xsl:attribute">
                                                    <xsl:attribute name="name" select="'actionNegationInd'"/>
                                                    <xsl:attribute name="select" select="'@negationInd'"/>
                                                </xsl:element>
                                            </xsl:element>
                                            <!-- End of attributes -->
                                            
                                            <xsl:element name="xsl:call-template">
                                                <xsl:attribute name="name" select="'infrastructureRootElements'"/>
                                            </xsl:element>
                                            
                                            <!-- Do ActRelationship stuff -->
                                            <xsl:call-template name="handleSpecificElements">
                                                <xsl:with-param name="in" select="concat($nm,'.',$hcdar2name)"/>
                                            </xsl:call-template>
                                            
                                            <xsl:element name="xsl:apply-templates">
                                                <xsl:attribute name="select" select="'self::*'"/>
                                                <xsl:attribute name="mode" select="$hctsub"/>
                                            </xsl:element>
                                            <!-- End of elements -->
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:if>
                            </xsl:when>
                            <!-- <xs:element name="realmCode" type="CS"  minOccurs="0" maxOccurs="unbounded"/> -->
                            <xsl:otherwise>
                                <xsl:if test="not($nm='POCD_MT000040.CustodianOrganization' and $cdar2name='id')">
                                    <xsl:element name="xsl:call-template">
                                        <xsl:attribute name="name" select="concat('dt-',$ctsub,'-to-',$ctr3sub)"/>

                                        <xsl:element name="xsl:with-param">
                                            <xsl:attribute name="name" select="'in'"/>
                                            <xsl:attribute name="select" select="concat('hl7:',$cdar2name)"/>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:comment> Skipping mapping of '<xsl:value-of select="concat($nm,'.',$cdar2name)"/>', because there is no matching '<xsl:value-of select="concat($nmuv,'.',$cdar3name)"/>' </xsl:comment>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            
            <xsl:element name="xsl:apply-templates">
                <xsl:attribute name="select"><xsl:text>*[not(namespace-uri()='urn:hl7-org:v3')]</xsl:text></xsl:attribute>
            </xsl:element>
            
        </xsl:element>
    </xsl:template>
    
    <xsl:template name="infrastructureRootElements">
        
        <xsl:comment> infrastructureRootElements </xsl:comment>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'infrastructureRootElements'"/>
            
            <!-- Do realmCode -->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-CS-to-DSET_CS'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'hl7:realmCode'"/>
                </xsl:element>
            </xsl:element>
            <!-- Do typeId -->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-II-to-II'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'hl7:typeId'"/>
                </xsl:element>
            </xsl:element>
            <!-- Do templateId -->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-II-to-DSET_II'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'hl7:templateId'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    
    <xsl:template name="handleSpecificAttributes">
        <xsl:param name="in"/>
        
        <xsl:choose>
            <xsl:when test="ends-with($in,'.patient') or $in='POCD_MT000040.Guardian.guardianPerson' or ends-with($in,'.assignedPerson') or ends-with($in,'.relatedPerson') or $in='POCD_MT000040.RelatedSubject.subject' or ends-with($in,'.associatedPerson')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PSN'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.relatedSubject')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PRS'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.providerOrganization') or ends-with($in,'.representedCustodianOrganization') or ends-with($in,'.receivedOrganization') or ends-with($in,'.representedOrganization') or ends-with($in,'.manufacturerOrganization') or ends-with($in,'.scopingOrganization') or ends-with($in,'.serviceProviderOrganization')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ORG'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.assignedAuthoringDevice')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'DEV'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.place')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PLC'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.assignedEntity') or $in='POCD_MT000040.InformationRecipient.intendedRecipient'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ASSIGNED'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.asOrganizationPartOf')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PART'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.IntendedRecipient.informationRecipient'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PSN'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.informationRecipient'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PRCP'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.documentationOf'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'DOC'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.inFulfillmentOf'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'FLFS'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.authorization'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'AUTH'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.componentOf' or $in='POCD_MT000040.Organizer.component'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'COMP'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.consumable')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'CSM'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.product')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PRD'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.specimen')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'SPC'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.performer')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PRF'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.author')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'AUT'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.informant')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INF'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Author.assignedAuthor'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ASSIGNED'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="not($in='POCD_MT000040.RelatedSubject.subject') and ends-with($in,'.subject')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'SBJ'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.informant')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INF'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Section.entry'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>if (../hl7:*[@typeCode='DRIV']) then ('DRIV') else ('COMP')</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Observation.referenceRange'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'REFV'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.wholeOrganization')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ORG'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.EncompassingEncounter.location'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'LOC'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Participant2.participantRole'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ROL'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ReferenceRange.observationRange' or $in='POCD_MT000040.Precondition.criterion'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'OBS'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'moodCode'"/>
                    <xsl:attribute name="select"><xsl:text>'EVN.CRT'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Reference.externalAct'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ACT'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'moodCode'"/>
                    <xsl:attribute name="select"><xsl:text>'EVN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Reference.externalDocument'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'DOC'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'moodCode'"/>
                    <xsl:attribute name="select"><xsl:text>'EVN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Reference.externalObservation'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'OBS'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'moodCode'"/>
                    <xsl:attribute name="select"><xsl:text>'EVN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Reference.externalProcedure'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PROC'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'moodCode'"/>
                    <xsl:attribute name="select"><xsl:text>'EVN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Location.healthCareFacility'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'SDLOC'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.InFulfillmentOf.order'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ACT'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.RelatedDocument.parentDocument'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'DOCCLIN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.HealthCareFacility.location'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PLC'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="ends-with($in,'.precondition')">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'typeCode'"/>
                    <xsl:attribute name="select"><xsl:text>'PRCN'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.Consumable.manufacturedProduct'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ROL'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ManufacturedProduct.manufacturedLabeledDrug' or $in='POCD_MT000040.ManufacturedProduct.manufacturedMaterial'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'MMAT'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ParticipantRole.playingEntity' or $in='POCD_MT000040.SpecimenRole.specimenPlayingEntity'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ENT'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ParticipantRole.playingDevice'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'DEV'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ParticipantRole.scopingEntity'">
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'classCode'"/>
                    <xsl:attribute name="select"><xsl:text>'ENT'</xsl:text></xsl:attribute>
                </xsl:element>
                <xsl:element name="xsl:attribute">
                    <xsl:attribute name="name" select="'determinerCode'"/>
                    <xsl:attribute name="select"><xsl:text>'INSTANCE'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="handleSpecificElements">
        <xsl:param name="in"/>
        
        <xsl:choose>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.documentationOf' or $in='POCD_MT000040.ClinicalDocument.inFulfillmentOf' or $in='POCD_MT000040.ClinicalDocument.authorization' or $in='POCD_MT000040.ClinicalDocument.componentOf' or $in='POCD_MT000040.ClinicalDocument.relatedDocument'">
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'blockedContextActRelationshipType'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'code'"/>
                        <xsl:attribute name="select"><xsl:text>'ART'</xsl:text></xsl:attribute>
                    </xsl:element>
                </xsl:element>
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'blockedContextParticipationType'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'code'"/>
                        <xsl:attribute name="select"><xsl:text>'PART'</xsl:text></xsl:attribute>
                    </xsl:element>
                </xsl:element>
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'actAttributeContextBlockedInd'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'value'"/>
                        <xsl:attribute name="select" select="'true()'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:when>
            <xsl:when test="$in='POCD_MT000040.ClinicalDocument.component' or $in='POCD_MT000040.StructuredBody.component' or $in='POCD_MT000040.Section.component' or $in='POCD_MT000040.Section.entry'">
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'blockedContextActRelationshipType'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'code'"/>
                        <xsl:attribute name="select"><xsl:text>'ART'</xsl:text></xsl:attribute>
                    </xsl:element>
                </xsl:element>
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'actAttributeContextBlockedInd'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'value'"/>
                        <xsl:attribute name="select" select="'false()'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="datatypeConversions">
        <xsl:comment> dt-AD-to-AD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-AD-to-AD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@use|$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                            
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:useablePeriod/hl7:low[@value]'"/>

                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'validTimeLow'"/>
                            <xsl:attribute name="select" select="'$in/hl7:useablePeriod/hl7:low/@value'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:useablePeriod/hl7:high[@value]'"/>

                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'validTimeHigh'"/>
                            <xsl:attribute name="select" select="'$in/hl7:useablePeriod/hl7:high/@value'"/>
                        </xsl:element>
                    </xsl:element>
                            
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/text()[string-length(normalize-space(.))&gt;0]|$in/hl7:*[not(self::hl7:useablePeriod)]'"/>

                        <xsl:element name="xsl:variable">
                            <xsl:attribute name="name" select="'partType'"/>
                            <xsl:element name="xsl:variable">
                                <xsl:attribute name="name" select="'partName'"/>
                                <xsl:attribute name="select" select="'local-name()'"/>
                            </xsl:element>

                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$postalMapping//map[@cdar2=$partName]/@cdar3'"/>
                            </xsl:element>
                        </xsl:element>

                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'part'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'{name()}'"/>
                                    <xsl:attribute name="select" select="'.'"/>
                                </xsl:element>
                            </xsl:element>

                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'string-length($partType)&gt;0'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'type'"/>
                                    <xsl:attribute name="select" select="'$partType'"/>
                                </xsl:element>
                            </xsl:element>

                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'value'"/>
                                <xsl:attribute name="select" select="'.'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-AD-to-COLL_AD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-AD-to-COLL_AD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-AD-to-DSET_AD'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'dt'"/>
                    <xsl:attribute name="select"><xsl:text>'DSET_AD'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-AD-to-DSET_AD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-AD-to-DSET_AD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[1]/@xsi:type or string-length($dt)&gt;0'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select"><xsl:text>'DSET_AD'</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                    
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'item'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'@use|@nullFlavor'"/>
                            
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'{name()}'"/>
                                    <xsl:attribute name="select" select="'.'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'hl7:useablePeriod/hl7:low[@value]'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'validTimeLow'"/>
                                    <xsl:attribute name="select" select="'hl7:useablePeriod/hl7:low/@value'"/>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'hl7:useablePeriod/hl7:high[@value]'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'validTimeHigh'"/>
                                    <xsl:attribute name="select" select="'hl7:useablePeriod/hl7:high/@value'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'text()[string-length(normalize-space(.))&gt;0]|hl7:*[not(self::hl7:useablePeriod)]'"/>
                                
                                <xsl:element name="xsl:variable">
                                    <xsl:attribute name="name" select="'partType'"/>
                                    <xsl:element name="xsl:variable">
                                        <xsl:attribute name="name" select="'partName'"/>
                                        <xsl:attribute name="select" select="'local-name()'"/>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:value-of">
                                        <xsl:attribute name="select" select="'$postalMapping//map[@cdar2=$partName]/@cdar3'"/>
                                    </xsl:element>
                                </xsl:element>

                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'part'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                                    
                                    <xsl:element name="xsl:for-each">
                                        <xsl:attribute name="select" select="'@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor'"/>
                                        
                                        <xsl:element name="xsl:attribute">
                                            <xsl:attribute name="name" select="'{name()}'"/>
                                            <xsl:attribute name="select" select="'.'"/>
                                        </xsl:element>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:if">
                                        <xsl:attribute name="test" select="'string-length($partType)&gt;0'"/>
                                        
                                        <xsl:element name="xsl:attribute">
                                            <xsl:attribute name="name" select="'type'"/>
                                            <xsl:attribute name="select" select="'$partType'"/>
                                        </xsl:element>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'value'"/>
                                        <xsl:attribute name="select" select="'.'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ANY-to-ANY </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ANY-to-ANY'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                <xsl:element name="xsl:choose">
                    <xsl:variable name="dt" as="xs:string*" select="('AD','BL','BN','CD','CE','CO','CV','ED','EIVL_TS','EN','II','INT','IVL_INT','IVL_MO','IVL_PQ','IVL_REAL','IVL_TS','MO','ON','PIVL_TS','PN','PQ','REAL','RTO_PQ_PQ','SC','ST','TEL','TS')"/>
                    <xsl:for-each select="$dt">

                        <xsl:element name="xsl:when">
                            <xsl:attribute name="test">
                                <xsl:text>$in/@xsi:type='</xsl:text>
                                <xsl:value-of select="."/>
                                <xsl:text>'</xsl:text>
                            </xsl:attribute>

                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="concat('dt-',.,'-to-',.)"/>

                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:for-each>
                    <xsl:element name="xsl:otherwise">
                        <xsl:element name="xsl:message">
                            <xsl:attribute name="terminate" select="'yes'"/>

                            <xsl:text> ERROR Found unsupported datatype '</xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in/@xsi:type'"/>
                            </xsl:element>
                            <xsl:text>' in </xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in[1]/name()'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-BL-to-BL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-BL-to-BL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@value|$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-BN-to-BN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-BN-to-BN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-BL-to-BL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CD-to-CD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@xsi:type]'"/>
                        
                        <xsl:element name="xsl:choose">
                            <xsl:element name="xsl:when">
                                <xsl:attribute name="test"><xsl:text>$in/@xsi:type='CO' or $in/@xsi:type='CS'</xsl:text></xsl:attribute>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'xsi:type'"/>
                                    <xsl:attribute name="select" select="'$in/@xsi:type'"/>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:otherwise">
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'xsi:type'"/>
                                    <xsl:attribute name="select"><xsl:text>'CD'</xsl:text></xsl:attribute>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion|$in/@nullFlavor'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@displayName]'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'displayName'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'value'"/>
                                <xsl:attribute name="select" select="'$in/@displayName'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:call-template">
                        <xsl:attribute name="name" select="'dt-ED-to-ED'"/>
                        
                        <xsl:element name="xsl:with-param">
                            <xsl:attribute name="name" select="'in'"/>
                            <xsl:attribute name="select" select="'$in/hl7:originalText'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <!-- FIXME: DTr2 does not have qualifier... copy as-is for now, but will lead to erroneous instances -->
                    <xsl:element name="xsl:call-template">
                        <xsl:attribute name="name" select="'dt-CR-to-DSET_CR'"/>
                        
                        <xsl:element name="xsl:with-param">
                            <xsl:attribute name="name" select="'in'"/>
                            <xsl:attribute name="select" select="'$in/hl7:qualifier'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:call-template">
                        <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                        
                        <xsl:element name="xsl:with-param">
                            <xsl:attribute name="name" select="'in'"/>
                            <xsl:attribute name="select" select="'$in/hl7:translation'"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CD-to-DSET_CD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CD-to-DSET_CD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@xsi:type]'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select"><xsl:text>'DSET_CD'</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <item xmlns="urn:hl7-org:v3">
                            
                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'{name()}'"/>
                                    <xsl:attribute name="select" select="'.'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'self::node()[@displayName]'"/>
                                
                                <displayName xmlns="urn:hl7-org:v3">
                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'value'"/>
                                        <xsl:attribute name="select" select="'@displayName'"/>
                                    </xsl:element>
                                </displayName>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-ED-to-ED'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:originalText'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <!-- FIXME: DTr2 does not have qualifier... copy as-is for now, but will lead to erroneous instances -->
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-CR-to-DSET_CR'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:qualifier'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:translation'"/>
                                </xsl:element>
                            </xsl:element>
                        </item>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CE-to-CE </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CE-to-CE'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CE-to-CD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CE-to-CD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CE-to-DSET_CD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CE-to-DSET_CD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-CD-to-DSET_CD'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CO-to-CO </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CO-to-CO'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                
                   <xsl:element name="xsl:if">
                       <xsl:attribute name="test" select="'$in[@code]'"/>
                       
                       <xsl:element name="xsl:element">
                           <xsl:attribute name="name" select="'code'"/>
                           <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion|$in/@nullFlavor'"/>
                            </xsl:element>
                    
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'$in[@displayName]'"/>

                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'displayName'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'value'"/>
                                        <xsl:attribute name="select" select="'$in/@displayName'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                    
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-ED-to-ED'"/>

                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in/hl7:originalText'"/>
                                </xsl:element>
                            </xsl:element>
                       </xsl:element>
                   </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CR-to-DSET_CR </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CR-to-DSET_CR'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                <xsl:element name="xsl:comment"> Could not map qualifier for: <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/hl7:name/@code|$in/hl7:name/@codeSystem|$in/hl7:name/@displayName|$in/hl7:value/@code|$in/hl7:value/@codeSystem|$in/hl7:value/@displayName'"/> <xsl:element name="xsl:value-of">
                            <xsl:attribute name="select"><xsl:text>concat(name(..),'/',name(),'=&quot;',.,'&quot; ')</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    <!--xsl:element name="xsl:copy-of">
                    <xsl:attribute name="select" select="'$in/self::*'"/>
                </xsl:element-->
                </xsl:element>
            </xsl:element>
            <!--xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@xsi:type]'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select"><xsl:text>'DSET_CR'</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <item xmlns="urn:hl7-org:v3">
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@inverted|@nullFlavor'"/>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-CV-to-CV'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:name'"/>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:value'"/>
                                </xsl:element>
                            </xsl:element>
                        </item>
                    </xsl:element>
                </xsl:element>
            </xsl:element-->
        </xsl:element>
        
        <xsl:comment> dt-CS-to-CS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CS-to-CS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CS-to-CD </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CS-to-CD'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CS-to-DSET_CS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CS-to-DSET_CS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                    
                        <item xmlns="urn:hl7-org:v3">
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@code|@nullFlavor'"/>
                            </xsl:element>
                        </item>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-CV-to-CV </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-CV-to-CV'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-CD-to-CD'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ED-to-ED </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ED-to-ED'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@mediaType|$in/@language|$in/@compression|$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    
                    <xsl:comment> SHA-1 is now SHA1 and SHA-256 is now SHA256 </xsl:comment>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/@integrityCheckAlgorithm'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'integrityCheckAlgorithm'"/>
                            <xsl:attribute name="select"><xsl:text>replace($in/@integrityCheckAlgorithm,'-','')</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/text()[string-length(normalize-space(.))&gt;0]'"/>
                        
                        <xsl:element name="xsl:choose">
                            <xsl:element name="xsl:when">
                                <xsl:attribute name="test">
                                    <xsl:text>$in/@representation='B64'</xsl:text>
                                </xsl:attribute>

                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'data'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                                    <xsl:element name="xsl:copy-of">
                                        <xsl:attribute name="select" select="'$in/text()[string-length(normalize-space(.))&gt;0]'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:otherwise">
                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'xml'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                                    <xsl:element name="xsl:copy-of">
                                        <xsl:attribute name="select" select="'$in/text()[string-length(normalize-space(.))&gt;0]'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/hl7:reference'"/>
                    </xsl:element>
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/hl7:thumbnail'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-EIVL_TS-to-EIVL_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-EIVL_TS-to-EIVL_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:event/@code'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'event'"/>
                            <xsl:attribute name="select" select="'$in/hl7:event/@code'"></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:offset'"/>
                        
                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-IVL_PQ-to-IVL_PQ'"/>
                            
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'$in/hl7:offset'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-EN-to-EN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-EN-to-EN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    <xsl:comment> @use code 'L' needs to be 'C'. Only one other code with an 'L' which is 'SYL'. Replace SYL, replace L, restore SYL </xsl:comment>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/@use'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'use'"/>
                            <xsl:attribute name="select"><xsl:text>replace(replace(replace($in/@use,'SYL','SYK'),'L','C'),'SYK','SYL')</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                            
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:validTime/hl7:low[@value]'"/>

                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'validTimeLow'"/>
                            <xsl:attribute name="select" select="'$in/hl7:validTime/hl7:low/@value'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:validTime/hl7:high[@value]'"/>

                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'validTimeHigh'"/>
                            <xsl:attribute name="select" select="'$in/hl7:validTime/hl7:high/@value'"/>
                        </xsl:element>
                    </xsl:element>
                            
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/text()[string-length(normalize-space(.))&gt;0]|$in/hl7:*[not(self::hl7:validTime)]'"/>
                        <xsl:element name="xsl:variable">
                            <xsl:attribute name="name" select="'partType'"/>
                            <xsl:element name="xsl:choose">
                                <xsl:element name="xsl:when">
                                    <xsl:attribute name="test" select="'self::hl7:given or self::hl7:prefix or self::hl7:suffix'"/>

                                    <xsl:element name="xsl:text">
                                        <xsl:text>GIV</xsl:text>
                                    </xsl:element>
                                </xsl:element>
                                <xsl:element name="xsl:when">
                                    <xsl:attribute name="test" select="'self::hl7:family'"/>

                                    <xsl:element name="xsl:text">
                                        <xsl:text>FAM</xsl:text>
                                    </xsl:element>
                                </xsl:element>
                                <xsl:element name="xsl:when">
                                    <xsl:attribute name="test" select="'self::hl7:delimiter'"/>

                                    <xsl:element name="xsl:text">
                                        <xsl:text>DEL</xsl:text>
                                    </xsl:element>
                                </xsl:element>
                                <xsl:element name="xsl:when">
                                    <xsl:attribute name="test" select="'self::hl7:title'"/>

                                    <xsl:element name="xsl:text">
                                        <xsl:text>TITLE</xsl:text>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                        <xsl:element name="xsl:variable">
                            <xsl:attribute name="name" select="'partQualifier'"/>
                            <xsl:element name="xsl:variable">
                                <xsl:attribute name="name" select="'partQualifierExtra'"/>
                                <xsl:element name="xsl:choose">
                                    <xsl:element name="xsl:when">
                                        <xsl:attribute name="test" select="'self::hl7:prefix'"/>

                                        <xsl:element name="xsl:text">
                                            <xsl:text> PFX</xsl:text>
                                        </xsl:element>
                                    </xsl:element>
                                    <xsl:element name="xsl:when">
                                        <xsl:attribute name="test" select="'self::hl7:suffix'"/>

                                        <xsl:element name="xsl:text">
                                            <xsl:text> SFX</xsl:text>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select">
                                    <xsl:text>normalize-space(concat(@qualifier,$partQualifierExtra))</xsl:text>
                                </xsl:attribute>
                            </xsl:element>
                        </xsl:element>

                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'part'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'{name()}'"/>
                                    <xsl:attribute name="select" select="'.'"/>
                                </xsl:element>
                            </xsl:element>

                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'string-length($partType)&gt;0'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'type'"/>
                                    <xsl:attribute name="select" select="'$partType'"/>
                                </xsl:element>
                            </xsl:element>

                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'value'"/>
                                <xsl:attribute name="select" select="'.'"/>
                            </xsl:element>

                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'string-length($partQualifier)&gt;0'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'qualifier'"/>
                                    <xsl:attribute name="select" select="'$partQualifier'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-EN-to-DSET_EN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-EN-to-DSET_EN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'item'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@nullFlavor|@xsi:type'"/>
                            </xsl:element>
                            <xsl:comment> @use code 'L' needs to be 'C'. Only one other code with an 'L' which is 'SYL'. Replace SYL, replace L, restore SYL </xsl:comment>
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'@use'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'use'"/>
                                    <xsl:attribute name="select"><xsl:text>replace(replace(replace(@use,'SYL','SYK'),'L','C'),'SYK','SYL')</xsl:text></xsl:attribute>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'hl7:validTime/hl7:low[@value]'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'validTimeLow'"/>
                                    <xsl:attribute name="select" select="'hl7:validTime/hl7:low/@value'"/>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'hl7:validTime/hl7:high[@value]'"/>
                                
                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'validTimeHigh'"/>
                                    <xsl:attribute name="select" select="'hl7:validTime/hl7:high/@value'"/>
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'text()[string-length(normalize-space(.))&gt;0]|hl7:*[not(self::hl7:validTime)]'"/>
                                <xsl:element name="xsl:variable">
                                    <xsl:attribute name="name" select="'partType'"/>
                                    <xsl:element name="xsl:choose">
                                        <xsl:element name="xsl:when">
                                            <xsl:attribute name="test" select="'self::hl7:given or self::hl7:prefix or self::hl7:suffix'"/>
                                            
                                            <xsl:element name="xsl:text">
                                                <xsl:text>GIV</xsl:text>
                                            </xsl:element>
                                        </xsl:element>
                                        <xsl:element name="xsl:when">
                                            <xsl:attribute name="test" select="'self::hl7:family'"/>
                                            
                                            <xsl:element name="xsl:text">
                                                <xsl:text>FAM</xsl:text>
                                            </xsl:element>
                                        </xsl:element>
                                        <xsl:element name="xsl:when">
                                            <xsl:attribute name="test" select="'self::hl7:delimiter'"/>
                                            
                                            <xsl:element name="xsl:text">
                                                <xsl:text>DEL</xsl:text>
                                            </xsl:element>
                                        </xsl:element>
                                        <xsl:element name="xsl:when">
                                            <xsl:attribute name="test" select="'self::hl7:title'"/>
                                            
                                            <xsl:element name="xsl:text">
                                                <xsl:text>TITLE</xsl:text>
                                            </xsl:element>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:element>
                                <xsl:element name="xsl:variable">
                                    <xsl:attribute name="name" select="'partQualifier'"/>
                                    <xsl:element name="xsl:variable">
                                        <xsl:attribute name="name" select="'partQualifierExtra'"/>
                                        <xsl:element name="xsl:choose">
                                            <xsl:element name="xsl:when">
                                                <xsl:attribute name="test" select="'self::hl7:prefix'"/>
                                                
                                                <xsl:element name="xsl:text">
                                                    <xsl:text> PFX</xsl:text>
                                                </xsl:element>
                                            </xsl:element>
                                            <xsl:element name="xsl:when">
                                                <xsl:attribute name="test" select="'self::hl7:suffix'"/>
                                                
                                                <xsl:element name="xsl:text">
                                                    <xsl:text> SFX</xsl:text>
                                                </xsl:element>
                                            </xsl:element>
                                        </xsl:element>
                                    </xsl:element>
                                    <xsl:element name="xsl:value-of">
                                        <xsl:attribute name="select"><xsl:text>normalize-space(concat(@qualifier,$partQualifierExtra))</xsl:text></xsl:attribute>
                                    </xsl:element>
                                </xsl:element>
                                
                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'part'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                                    
                                    <xsl:element name="xsl:for-each">
                                        <xsl:attribute name="select" select="'@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor'"/>
                                        
                                        <xsl:element name="xsl:attribute">
                                            <xsl:attribute name="name" select="'{name()}'"/>
                                            <xsl:attribute name="select" select="'.'"/>
                                        </xsl:element>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:if">
                                        <xsl:attribute name="test" select="'string-length($partType)&gt;0'"/>
                                        
                                        <xsl:element name="xsl:attribute">
                                            <xsl:attribute name="name" select="'type'"/>
                                            <xsl:attribute name="select" select="'$partType'"/>
                                        </xsl:element>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'value'"/>
                                        <xsl:attribute name="select" select="'.'"/>
                                    </xsl:element>
                                    
                                    <xsl:element name="xsl:if">
                                        <xsl:attribute name="test" select="'string-length($partQualifier)&gt;0'"/>
                                        
                                        <xsl:element name="xsl:attribute">
                                            <xsl:attribute name="name" select="'qualifier'"/>
                                            <xsl:attribute name="select" select="'$partQualifier'"/>
                                        </xsl:element>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-II-to-II </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-II-to-II'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@root|$in/@extension|$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-II-to-DSET_II </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-II-to-DSET_II'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        <item xmlns="urn:hl7-org:v3">
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@root|@extension|@nullFlavor|@xsi:type'"/>
                            </xsl:element>
                        </item>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-INT-to-INT </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-INT-to-INT'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-INT-to-ST </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-INT-to-ST'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'value'"/>
                        <xsl:attribute name="select" select="'$in/@value'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <!-- TODO: Check PQR and attributes on low/high/center/width -->
        <xsl:comment> dt-IVL-to-IVL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{if (string-length($nm)&gt;0) then ($nm) else (name($in))}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'string-length($dt)&gt;0'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select" select="'$dt'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:low/@inclusive'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'lowClosed'"/>
                            <xsl:attribute name="select" select="'$in/hl7:low/@inclusive'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:high/@inclusive'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'highClosed'"/>
                            <xsl:attribute name="select" select="'$in/hl7:high/@inclusive'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/hl7:low|$in/hl7:high|$in/width'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'{name()}'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@value|@unit|@nullFlavor'"/>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-PQR-to-PQR'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'hl7:translation'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[hl7:center]'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'any'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'$in/hl7:center/@value|$in/hl7:center/@unit|$in/hl7:center/@nullFlavor'"/>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-PQR-to-PQR'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in/hl7:center/hl7:translation'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@value or hl7:translation]'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'any'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'$in/@value|$in/@unit|$in/@nullFlavor'"/>
                            </xsl:element>
                            
                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="'dt-PQR-to-PQR'"/>
                                
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in/hl7:translation'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_INT-to-IVL_INT </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_INT-to-IVL_INT'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_MO-to-IVL_MO </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_MO-to-IVL_MO'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_PQ-to-IVL_PQ </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_PQ-to-IVL_PQ'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_PQ-to-PQ </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_PQ-to-PQ'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@unit|$in/@value'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/hl7:center/@value|$in/hl7:center/@unit|$in/hl7:center/@nullFlavor'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:center/hl7:translation'"/>

                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-PQR-to-PQR'"/>

                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'$in/hl7:center/hl7:translation'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-PQR-to-PQR </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-PQR-to-PQR'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:for-each">
                    <xsl:attribute name="select" select="'$in'"/>
                    
                    <xsl:element name="xsl:element">
                        <xsl:attribute name="name" select="'{name()}'"/>
                        <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                        <xsl:element name="xsl:copy-of">
                            <xsl:attribute name="select" select="'@code|@codeSystem|codeSystemName|@codeSystemVersion|@nullFlavor|@value'"/>
                        </xsl:element>

                        <xsl:element name="xsl:if">
                            <xsl:attribute name="test" select="'self::node()[@displayName]'"/>

                            <xsl:element name="xsl:element">
                                <xsl:attribute name="name" select="'displayName'"/>
                                <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                                <xsl:element name="xsl:attribute">
                                    <xsl:attribute name="name" select="'value'"/>
                                    <xsl:attribute name="select" select="'@displayName'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>

                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-ED-to-ED'"/>

                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'hl7:originalText'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_REAL-to-IVL_REAL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_REAL-to-IVL_REAL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_TS-to-IVL_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_TS-to-IVL_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-IVL-to-IVL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'nm'"/>
                    <xsl:attribute name="select" select="'$nm'"/>
                </xsl:element>
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'dt'"/>
                    <xsl:attribute name="select" select="'$dt'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-IVL_TS-to-QSET_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-IVL_TS-to-QSET_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor'"/>
                    </xsl:element>
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'xsi:type'"/>
                        <xsl:attribute name="select"><xsl:text>'IVL_TS'</xsl:text></xsl:attribute>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:low/@inclusive'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'lowClosed'"/>
                            <xsl:attribute name="select" select="'$in/hl7:low/@inclusive'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/hl7:high/@inclusive'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'highClosed'"/>
                            <xsl:attribute name="select" select="'$in/hl7:high/@inclusive'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/hl7:low|$in/hl7:high|$in/width'"/>

                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'{name()}'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@* except @inclusive'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>

                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[hl7:center]'"/>

                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'any'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'$in/hl7:center/@value|$in/hl7:center/@nullFlavor'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>

                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@value]'"/>

                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'any'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'value'"/>
                                <xsl:attribute name="select" select="'$in/@value'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-MO-to-MO </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-MO-to-MO'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ON-to-ON </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ON-to-ON'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-EN-to-EN'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ON-to-DSET_EN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ON-to-DSET_EN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-EN-to-DSET_EN'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ON-to-EN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ON-to-EN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-EN-to-EN'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-PIVL_TS-to-PIVL_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-PIVL_TS-to-PIVL_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{if (string-length($nm)&gt;0) then ($nm) else (name($in))}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:call-template">
                        <xsl:attribute name="name" select="'dt-IVL_TS-to-IVL_TS'"/>
                        
                        <xsl:element name="xsl:with-param">
                            <xsl:attribute name="name" select="'in'"/>
                            <xsl:attribute name="select" select="'$in/hl7:phase'"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:call-template">
                        <xsl:attribute name="name" select="'dt-PQ-to-PQ'"/>
                        
                        <xsl:element name="xsl:with-param">
                            <xsl:attribute name="name" select="'in'"/>
                            <xsl:attribute name="select" select="'$in/hl7:period'"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-PN-to-PN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-PN-to-PN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-EN-to-EN'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-PN-to-DSET_EN </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-PN-to-DSET_EN'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-EN-to-DSET_EN'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-PQ-to-PQ </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-PQ-to-PQ'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-REAL-to-REAL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-REAL-to-REAL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-RTO_PQ_PQ-to-RTO_PQ_PQ </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-RTO_PQ_PQ-to-RTO_PQ_PQ'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'xsi:type'"/>
                        <xsl:attribute name="select"><xsl:text>'RTO'</xsl:text></xsl:attribute>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in/hl7:numerator|$in/hl7:denominator'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'{name()}'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@*'"/>
                            </xsl:element>
                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'xsi:type'"/>
                                <xsl:attribute name="select"><xsl:text>'PQ'</xsl:text></xsl:attribute>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-RTO_PQ_PQ-to-DSET_RTO </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-RTO_PQ_PQ-to-DSET_RTO'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@xsi:type'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <item xmlns="urn:hl7-org:v3">
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@*'"/>
                            </xsl:element>
                            
                            <xsl:element name="xsl:for-each">
                                <xsl:attribute name="select" select="'hl7:numerator|hl7:denominator'"/>
                                
                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'{name()}'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                                    
                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'xsi:type'"/>
                                        <xsl:attribute name="select"><xsl:text>'PQ'</xsl:text></xsl:attribute>
                                    </xsl:element>
                                    <xsl:element name="xsl:copy-of">
                                        <xsl:attribute name="select" select="'@*'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </item>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-SC-to-SC </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-SC-to-SC'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@language|$in/@xsi:type'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in/text()[string-length(.)&gt;0]'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'value'"/>
                            <xsl:attribute name="select" select="'$in/text()'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'count($in/@displayName|$in/@code)&gt;0'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'code'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                        
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion'"/>
                            </xsl:element>
                    
                            <xsl:element name="xsl:if">
                                <xsl:attribute name="test" select="'$in[@displayName]'"/>

                                <xsl:element name="xsl:element">
                                    <xsl:attribute name="name" select="'displayName'"/>
                                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>

                                    <xsl:element name="xsl:attribute">
                                        <xsl:attribute name="name" select="'value'"/>
                                        <xsl:attribute name="select" select="'$in/@displayName'"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-ST-to-ST </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-ST-to-ST'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'value'"/>
                        <xsl:attribute name="select" select="'$in/text()'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-SXCM_TS-to-SXCM_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-SXCM_TS-to-SXCM_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                <xsl:element name="xsl:choose">
                    <xsl:variable name="dt" as="xs:string*" select="('IVL_TS','PIVL_TS','EIVL_TS','TS')"/>
                    <xsl:for-each select="$dt">

                        <xsl:element name="xsl:when">
                            <xsl:attribute name="test">
                                <xsl:text>$in/@xsi:type='</xsl:text>
                                <xsl:value-of select="."/>
                                <xsl:text>'</xsl:text>
                            </xsl:attribute>

                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="concat('dt-',.,'-to-',.)"/>

                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in'"/>
                                </xsl:element>
                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'nm'"/>
                                    <xsl:attribute name="select" select="'$nm'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:for-each>
                    <xsl:element name="xsl:when">
                        <xsl:attribute name="test" select="'not($in/@xsi:type)'"/>  
                        
                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-IVL_TS-to-IVL_TS'"/>
                            
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'$in'"/>
                            </xsl:element>
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'nm'"/>
                                <xsl:attribute name="select" select="'$nm'"/>
                            </xsl:element>
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'dt'"/>
                                <xsl:attribute name="select"><xsl:text>'IVL_TS'</xsl:text></xsl:attribute>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:otherwise">
                        <xsl:element name="xsl:message">
                            <xsl:attribute name="terminate" select="'yes'"/>

                            <xsl:text> ERROR Found unsupported datatype '</xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in/@xsi:type'"/>
                            </xsl:element>
                            <xsl:text>' in </xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in[1]/name()'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-SXCM_TS-to-IVL_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-SXCM_TS-to-IVL_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                <xsl:element name="xsl:choose">
                    <xsl:variable name="dt" as="xs:string*" select="('IVL_TS')"/>
                    <xsl:for-each select="$dt">

                        <xsl:element name="xsl:when">
                            <xsl:attribute name="test">
                                <xsl:text>$in/@xsi:type='</xsl:text>
                                <xsl:value-of select="."/>
                                <xsl:text>'</xsl:text>
                            </xsl:attribute>

                            <xsl:element name="xsl:call-template">
                                <xsl:attribute name="name" select="concat('dt-',.,'-to-',.)"/>

                                <xsl:element name="xsl:with-param">
                                    <xsl:attribute name="name" select="'in'"/>
                                    <xsl:attribute name="select" select="'$in'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:for-each>
                    <xsl:element name="xsl:when">
                        <xsl:attribute name="test" select="'$in[not(@xsi:type)]'"/>
                        
                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-IVL_TS-to-IVL_TS'"/>
                            
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'$in'"/>
                            </xsl:element>
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'dt'"/>
                                <xsl:attribute name="select" select="'IVL_TS'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                    <xsl:element name="xsl:otherwise">
                        <xsl:element name="xsl:message">
                            <xsl:attribute name="terminate" select="'yes'"/>

                            <xsl:text> ERROR Found unsupported datatype '</xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in/@xsi:type'"/>
                            </xsl:element>
                            <xsl:text>' in </xsl:text>
                            <xsl:element name="xsl:value-of">
                                <xsl:attribute name="select" select="'$in[1]/name()'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <!-- TODO: optimize for when there's only one input value -->
        <xsl:comment> dt-SXCM_TS-to-QSET_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-SXCM_TS-to-QSET_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:attribute">
                        <xsl:attribute name="name" select="'xsi:type'"/>
                        <xsl:attribute name="select"><xsl:text>'QSI_TS'</xsl:text></xsl:attribute>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <xsl:element name="xsl:call-template">
                            <xsl:attribute name="name" select="'dt-SXCM_TS-to-SXCM_TS'"/>
                            
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'in'"/>
                                <xsl:attribute name="select" select="'.'"/>
                            </xsl:element>
                            <xsl:element name="xsl:with-param">
                                <xsl:attribute name="name" select="'nm'"/>
                                <xsl:attribute name="select"><xsl:text>'term'</xsl:text></xsl:attribute>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-StrucDoc.Text-to-ED </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-StrucDoc.Text-to-ED'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in)}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:comment> TODO: @ID and @styleCode seem no longer supported in ED... missing anything without them? </xsl:comment>
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@mediaType|$in/@language'"/>
                    </xsl:element>
                    
                    <xsl:comment> TODO: copying any text content into text/xml regardless. Need more intelligent copying? </xsl:comment>
                    <xsl:element name="xsl:element">
                        <xsl:attribute name="name" select="'xml'"/>
                        <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                        <xsl:element name="xsl:copy-of">
                            <xsl:attribute name="select" select="'$in/node()'"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-TEL-to-TEL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-TEL-to-TEL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-TEL-to-COLL_TEL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-TEL-to-COLL_TEL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:call-template">
                <xsl:attribute name="name" select="'dt-TEL-to-DSET_TEL'"/>
                
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'in'"/>
                    <xsl:attribute name="select" select="'$in'"/>
                </xsl:element>
                <xsl:element name="xsl:with-param">
                    <xsl:attribute name="name" select="'dt'"/>
                    <xsl:attribute name="select"><xsl:text>'DSET_AD'</xsl:text></xsl:attribute>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-TEL-to-DSET_TEL </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-TEL-to-DSET_TEL'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{name($in[1])}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[1]/@xsi:type or string-length($dt)&gt;0'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select"><xsl:text>'DSET_TEL'</xsl:text></xsl:attribute>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:for-each">
                        <xsl:attribute name="select" select="'$in'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'item'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:copy-of">
                                <xsl:attribute name="select" select="'@use|@value|@nullFlavor'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-TS-to-TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-TS-to-TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{if (string-length($nm)&gt;0) then ($nm) else (name($in))}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@value|$in/@nullFlavor|$in/@xsi:type'"/>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'string-length($dt)&gt;0'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select" select="'$dt'"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> dt-TS-to-IVL_TS </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="name" select="'dt-TS-to-IVL_TS'"/>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'in'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'nm'"/>
            </xsl:element>
            <xsl:element name="xsl:param">
                <xsl:attribute name="name" select="'dt'"/>
            </xsl:element>
            
            <!--xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'$in/self::*'"/>
            </xsl:element-->
            <xsl:element name="xsl:if">
                <xsl:attribute name="test" select="'not(empty($in))'"/>
                
                <xsl:element name="xsl:element">
                    <xsl:attribute name="name" select="'{if (string-length($nm)&gt;0) then ($nm) else (name($in))}'"/>
                    <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                    
                    <xsl:element name="xsl:copy-of">
                        <xsl:attribute name="select" select="'$in/@nullFlavor'"/>
                    </xsl:element>
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'string-length($dt)&gt;0'"/>
                        
                        <xsl:element name="xsl:attribute">
                            <xsl:attribute name="name" select="'xsi:type'"/>
                            <xsl:attribute name="select" select="'$dt'"/>
                        </xsl:element>
                    </xsl:element>
                    
                    <xsl:element name="xsl:if">
                        <xsl:attribute name="test" select="'$in[@value]'"/>
                        
                        <xsl:element name="xsl:element">
                            <xsl:attribute name="name" select="'any'"/>
                            <xsl:attribute name="namespace" select="'urn:hl7-org:v3'"/>
                            
                            <xsl:element name="xsl:attribute">
                                <xsl:attribute name="name" select="'value'"/>
                                <xsl:attribute name="select" select="'$in/@value'"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    
    <xsl:template name="fallbackConversions">
        <xsl:comment> processing-instruction()|comment()|text() </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="match" select="'processing-instruction()|comment()|text()'"/>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'self::node()'"/>
            </xsl:element>
        </xsl:element>
        
        <xsl:comment> copy any other node as-is </xsl:comment>
        <xsl:text>&#10;</xsl:text>
        <xsl:element name="xsl:template">
            <xsl:attribute name="match" select="'*'"/>
            
            <xsl:element name="xsl:copy-of">
                <xsl:attribute name="select" select="'self::node()'"/>
            </xsl:element>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>