<?xml version="1.0" encoding="UTF-8"?>
<pattern id="datatypes-sch" xmlns="http://purl.oclc.org/dsdl/schematron">
    <title>Elementen</title>
    <!-- Test op lege elementen, Place is vooralsnog uitgesloten -->
    <rule context="*[(not(self::hl7:Place) and not(self::hl7:br)) and not(*) and (not(@*) or (count(@*)=1 and @xsi:type)) and string-length(normalize-space(text()[1]))=0]">
        <assert test="not(.)">Lege elementen zijn niet toegestaan</assert>
    </rule>
    
    <title>Attributen</title>
    <!-- Test op elementen met lege attributen -->
    <!-- AH: Merk op: als context="*" dan slaat de Schematron engine verder alle rules over. 
        Vandaar dat ik de * heb gewijzigd in onderstaande constructie waarna een rule staat 
        die gewoon altijd af moet gaan. Wellicht ziet het er vreemd uit, maar het werkt. -->
    <!--rule context="*[count(@*[string-length(normalize-space(.))=0])&gt;0]"-->
    <rule context="*[@*[normalize-space()='']]">
        <assert test="not(.)">Lege attributen zijn niet toegestaan.</assert>
    </rule>
    
    <title>Adressen</title>
    <rule context="hl7:postalCode[not(ancestor::hl7:value)]">
        <!-- Test formaat postcode -->
        <!-- Lower case naar upper case NEDRLA -->
        <let name="countryCode" value="upper-case(normalize-space(.))"/>
        <assert test="text() or @code">Postcodes moeten in de text-node of in de code staan</assert>
        <assert test="if (@codeSystem='2.16.840.1.113883.2.4.4.15') then (
            matches(@code,'^[0-9]{4}[A-Z]{2}$')
            ) else ( 1=1 )"
            >Postcodes onder codeSystem '2.16.840.1.113883.2.4.4.15' moeten voldoen aan het formaat 9999AA</assert>
        <assert
            test="if (text() and (not(../hl7:country) or ../hl7:country[
            (@code='NL' and (@codeSystem='2.16.1' or @codeSystem='1.3.6.1.4.1.1466.115.121.1.11' or @codeSystem='1.0.3166.1.2.2')) or
            (@code='NLD' and @codeSystem='2.16.2') or
            (@code='528' and @codeSystem='2.16.3') or
            $countryCode='NL' or
            $countryCode='NLD' or
            $countryCode='NEDERLAND'
            ])) then ( matches(.,'^[0-9]{4} [A-Z]{2}$') ) else ( 1=1)"
            >Geen land opgegeven, of land is Nederland en postcode voldoet niet aan het formaat 9999 AA.</assert>
    </rule>
    <rule context="hl7:addr">
        <!-- Test op mixed content en lege adressen -->
        <assert test="(count(*)>0 and string-length(normalize-space(text()[1]))=0) or count(*)=0">Mixed content is niet toegestaan.</assert>
    </rule>
    
    <title>Telecom</title>
    <!-- 
        Getest met: <telecom use="HP" value="tel:+31190531770"/>
      <telecom use="HP" value="tel:+31-(0)190531770%20;isub=1%2023"/>
      <telecom value="tel:41234567"/>
      <telecom value="tel:01041234567"/>
      <telecom value="mailto:afdsf.-.b@b.nl"/>
      <telecom value="http://www.nictiz.nl:8080/directory"/>
      <telecom value="http://tools.ietf.org/html/rfc2616"/>
      <telecom value="http://abc.com:80/~smith/home.html"/>
      <telecom value="http://ABC.com/%7Esmith/home.html"/>
      <telecom value="http://ABC.com:/%7esmith/home.html"/>
      <telecom
          value="http://www.linkedin.com/memberInvite?acceptInvitation=&amp;invitationID=775190257&amp;sharedKey=DT2gs65T&amp;itemID=I1478332986_2&amp;goback=%2Emml_inbox_none_DATE_1"/>
      <telecom value="http://www.google.com/search?client=safari&amp;rls=en&amp;q=http&amp;ie=UTF-&amp;&amp;oe=UTF-8"/>
      <telecom
          value="http://googleads.g.doubleclick.net/pagead/ads?client=ca-pub-6744919314769019&amp;format=fp_al_lp&amp;output=html&amp;h=15&amp;w=728&amp;ea=0&amp;flash=10.0.32&amp;url=http%3A%2F%2Fwww.asciitable.com%2F&amp;dt=1254481943190&amp;prev_fmts=728x15_0ads_al_s&amp;correlator=1254481943041&amp;frm=0&amp;ga_vid=144077625.1254481943&amp;ga_sid=1254481943&amp;ga_hid=1308288403&amp;ga_fc=0&amp;u_tz=120&amp;u_his=2&amp;u_java=1&amp;u_h=900&amp;u_w=1440&amp;u_ah=874&amp;u_aw=1440&amp;u_cd=24&amp;u_nplug=12&amp;u_nmime=126&amp;biw=1280&amp;bih=764&amp;fu=0&amp;ifi=2&amp;dtd=19&amp;kw_type=radlink&amp;rt=ChBKxeAdAAfWUgreC87p9BZcEhFFQkNESUMgQ29udmVyc2lvbhoI4oCu6eKAF3Qg-t7QxAIoAUj63tDEAlITCOSh6Lednp0CFRMv3godeiF75w&amp;hl=en&amp;kw0=Hex+Tool&amp;kw1=EBCDIC+Hex&amp;kw2=EBCDIC+ASCII&amp;kw3=EBCDIC+Conversion&amp;kw4=EBCDIC+Table&amp;okw=EBCDIC+Conversion"/>
      <telecom value="http://www.google.com/url?ct=abg&amp;pa="/>
      <telecom value="http://www.google.com/url?ct=abg&amp;q=https://www.google.com/adsense/support/bin/request.py#dsffsd*!"/>
      <telecom
          value="http://www.google.com/url?ct=abg&amp;q=https://www.google.com/adsense/support/bin/request.py%3Fcontact%3Dabg_afc%26url%3Dhttp://www.asciitable.com/%26hl%3Den%26client%3Dca-pub-6744919314769019%26adU%3Dwww.intodq.com%26adT%3DValue%2Byour%2Bdata%26adU%3Dwww.pervasivedatatools.com%26adT%3Dascii%2Bebcdic%2Btranscoding%26adU%3Dwww.softwaremining.com%26adT%3DCobol%2BTo%2BOO%2BJava/C%2523%26adU%3Dwww.dbload.com%26adT%3DData%2BExport%2B%2526amp%253B%2BImport%2BTool%26adU%3Dwww.metex.com%26adT%3DApplication%2BModernization%26adU%3Dwww.Import-Usa-Cars.nl/Vans%26adT%3DImport%2BUSA%2BCars%26adU%3Dwww.CobolProducts.com/datafile/%26adT%3DConvert%2BCobol%2BData%2BFiles%26adU%3Dwww.Transend.com/EmailConversion%26adT%3DEmail%2BConversion%2BSoftware%26adU%3Dwww.skills-1st.co.uk%26adT%3DTDI%2BExpert%26adU%3Dwww.TransTOOLs.com%26adT%3DGo%2Bto%2BJava,%2BGo%2BNow%26gl%3DNL&amp;usg=AFQjCNF7NyJM3uxA3m7VTHZLcNFjzVOdwA"/>
      <telecom value="http://user:pass@www.mysite.com/dir/?section=other&amp;auth=Jane+Smith+writing+as+J.+N.+Doe"/>
      <telecom value="tel:+1-201-555-0123"/>
      <telecom value="tel:+1-201-555-0123;ext=4324;parameter=moeder"/>
      <telecom value="tel:7042;phone-context=example.com"/>
      <telecom value="tel:863-1234;phone-context=+1-914-555"/>
      <telecom value="tel:863-1234;phone-context=+1-914-555;phone-context=example.com"/>
      <telecom value="mllp://1.10.1.1:mllp/"/>
      <telecom value="mllp://www.enovation.nl:8/"/>
      <telecom value="ftp://user:pass@10.10.10.10:21"/>
      <telecom value="ftp://10.10.10.10"/>
      <telecom value="ftp://10.10.10.10:21"/>
      <telecom value="ftp://10.10.10.10:21/"/>
      <telecom value="ftp://ftphost.org"/>
      <telecom value="ftp://ftphost.org/"/>
      <telecom value="ftp://ftphost.org:ftp/"/>
      <telecom value="ftp://ftphost.org:ftp/;type=i"/>
      <telecom value="ftp://ftphost.org:ftp/dir/di-r/na$$%a0&amp;me;type=i"/>
      <telecom value="file://c:/filename.txt"/>
      <telecom value="file://c:/filename/file%7c"/>
      <telecom value="file://host.org/filename.txt"/>
      <telecom value="nfs://host.org/filename.txt"/>
      <telecom value="nfs://host.org//filename.txt"/>
      <telecom value="telnet://10.10.10.10"/>
      <telecom value="telnet://10.10.10.10:21"/>
      <telecom value="telnet://10.10.10.10:21/"/>
      <telecom value="telnet://ftphost.org"/>
      <telecom value="telnet://ftphost.org/"/>
      <telecom value="telnet://ftphost.org:ftp/"/>
      <telecom value="x-hl7-applicatie:2.16.840.1.113883.2.4.6.6.7000324"/>
    -->
    <rule context="hl7:telecom">
        <assert test="@value">Telecom elementen moeten een value attribuut hebben.</assert>
        <assert test="@value=iri-to-uri(@value)">Een telecom value moet een geldige URI zijn, bijvoorbeeld '<value-of select="iri-to-uri(@value)"
            />'.</assert>

        <let name="urlScheme" value="substring-before(@value,':')"/>
        <assert test="@value and document('../vocab/URL.urlScheme.xml')/*/hl7:code[@code=$urlScheme]">Telecom value heeft ongeldig URL scheme
                '<value-of select="$urlScheme"/>'</assert>

        <!-- tel en fax -->
        <let name="urlStr" value="substring-after(@value,':')"/>
        <!-- Known issue: isub vrij formaat parameters ondersteunen geen apostroph alhoewel dat legaal is. Krijg het niet vooral elkaar om die te escapen -->
        <assert
            test="if ($urlScheme='tel' or $urlScheme='fax') then (
        matches($urlStr,'^(\+?([\d()./-]|(%[a-f\d]{2}))+)*(;(phone-context=((\+?([\d()./-]|(%[a-f\d]{2}))+)|(([a-z\d-]|(%[a-f\d]{2}))+(\.([a-z\d-]|(%[a-f\d]{2}))+)*))|(ext=[\d./-]+)|(isub=(([a-z\d();/?:@&amp;=+$,_.!~*-])|(%[a-f\d]{2}))+)|([a-z\d-]+=([a-z\d\[\]/:&amp;+$_.!~*()-]|(%[a-f\d]{2}))+)))*$')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc3966">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 3966</assert>

        <!-- file -->
        <assert
            test="if ($urlScheme='file') then (
        matches($urlStr,'^///{0,2}((((([1-2]\d{0,2})(\.([1-2]\d{0,2})){3})|(([\w-]+\.)+([a-z]+))))|([a-z][:|]))(/(([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))*)*$','i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc1738">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 1738.</assert>

        <!-- nfs -->
        <assert
            test="if ($urlScheme='nfs') then (
        matches($urlStr,'^//((((([1-2]\d{0,2})(\.([1-2]\d{0,2})){3})|(([\w-]+\.)+([a-z]+))))|([a-z][:|]))/?(/(([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))*)*$','i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc2224">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 2224.</assert>

        <!-- ftp en ftps -->
        <!-- Merk op: interne hostnamen niet ondersteund -->
        <assert
            test="if ($urlScheme='ftp' or $urlScheme='ftps') then (
        matches($urlStr,'^//((([a-z\d$\.+!*(),?&amp;=~_-])|(%[a-f\d]{2}))+(:(([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))*)?@)?((([1-2]\d{0,2})(\.([1-2]\d{0,2})){3})|(([\w-]+\.)+(aero|arpa|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|[a-z]{2})))(:(([1-9]\d{0,4})|([a-z][\w-]*))?)?(/(([a-z\d$\.+!*(),?&amp;_~=-])|(%[a-f\d]{2}))*)*(;type=[aid])?$','i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc1738">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 1738.</assert>

        <!-- http en https
            http_URL = "http:" "//" host [ ":" port ] [ abs_path [ "?" query ]]
        -->
        <!-- Merk op: interne hostnamen niet ondersteund -->
        <assert
            test="if ($urlScheme='http' or $urlScheme='https') then (
            matches($urlStr,'^//((([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))+(:(([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))*)?@)?((([1-2]\d{0,2})(\.([1-2]\d{0,2})){3})|(([\w-]+\.)+(aero|arpa|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|[a-z]{2})))(:(([1-9]\d{0,4})|([a-z]\w*))?)?(/(([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))*)*(\?(([\w$_\.+;:@~!*(),])|(%[a-f\d]{2}))+=(([\w$_\.+;:/@~!*(),-])|(%[a-f\d]{2}))*(&amp;((([\w$_\.+;:@~!*(),])|(%[a-f\d]{2}))+=(([\w$_\.+;:/@~!*(),-])|(%[a-f\d]{2}))*)?)*)?(#([\w~!$+|.,*:=~_]|%[a-f\d]{2})*)?$', 'i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc1738">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 1738</assert>

        <!-- telnet://<user>:<password>@<host>:<port>/ -->
        <!-- Merk op: interne hostnamen niet ondersteund -->
        <assert
            test="if ($urlScheme='telnet') then (
        matches($urlStr,'^//((([a-z\d$\.+!*(),?&amp;~_=-])|(%[a-f\d]{2}))+(:(([a-z\d$\.+!*(),?&amp;=-])|(%[a-f\d]{2}))*)?@)?((([1-2]\d{0,2})(\.([1-2]\d{0,2})){3})|(([\w-]+\.)+(aero|arpa|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|[a-z]{2})))(:(([1-9]\d{0,4})|([a-z]\w*))?)?(/(([a-z\d$\.+!*(),?&amp;=-])|(%[a-f\d]{2}))*)*$','i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc1738">Dit is geen geldige <value-of select="$urlScheme"/> URL volgens RFC 1738.</assert>

        <!-- mailto -->
        <assert
            test="if ($urlScheme='mailto') then (
        matches($urlStr,'^[a-z\d_\+-]+(\.[a-z\d_\+-]+)*@\w+(\.\w+)*\.([a-z]{2,4})$','i')
        ) else (1=1)"
            see="http://tools.ietf.org/html/rfc2368">Dit is geen geldig e-mailadres volgens RFC 2368. Merk op dat het niet toegestaan is extra headers
            op te nemen.</assert>

        <!-- x-hl7-applicatie -->
        <assert
            test="if ($urlScheme='x-hl7-applicatie') then (
        matches($urlStr,'^2\.16\.840\.1\.113883\.2\.4\.6\.6\.[1-9]\d+$')
        ) else (1=1)"
            >Dit is geen geldig HL7 applicatie-id. Een geldig applicatie-id begint met "2.16.840.1.113883.2.4.6.6." gevolgd door een numeriek
            deel.</assert>

        <!-- mllp -->
        <!-- Merk op: interne hostnamen niet ondersteund -->
        <assert
            test="if ($urlScheme='mllp') then (
        matches($urlStr,'^//(([1-2]\d{0,2})(\.([1-2]\d{0,2})){3}|(([\w-]+\.)+(aero|arpa|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|[a-z]{2}))):(([1-9]\d{0,4})|([A-Za-z]\w*))/$')
        ) else (1=1)"
            >Dit is geen geldige mllp URL. Een geldige mllp URL heeft de vorm mllp://host:port/ waarbij 'host' een naam of IP kan zijn en 'port' een
            benoemde poort of een nummer.</assert>

    </rule>
    <title>Namen algemeen</title>
    <rule context="hl7:name">
        <!-- Test op mixed content en lege namen -->
        <assert test="(count(*)>0 and string-length(normalize-space(text()[1]))=0) or (count(*)=0 and string-length(normalize-space(text()[1]))>0)"
            >Mixed content is niet toegestaan en name mag niet leeg zijn.</assert>
    </rule>
    <rule context="hl7:name/*">
        <!-- Test op lege elementen -->
        <report test="normalize-space(.)=''">Lege elementen zijn niet toegestaan.</report>
    </rule>
    <!-- Test of voorvoegsels eindigen met een spatie -->
    <rule context="hl7:name/hl7:prefix[@qualifier='VV']">
        <assert test="substring(text(),string-length(text()),1)=' '">prefix elementen met qualifier=VV moeten eindigen met een spatie.</assert>
    </rule>
    <title>Namen van Personen</title>
    <!-- Test of voorvoegsels in de achternaam zijn opgenomen -->
    <rule context="hl7:name/hl7:family[@qualifier='BR']">
        <assert test="not(substring(.,1,4)='van ') and not(substring(.,1,3)='de ')">Voorvoegsels mogen niet in de achternaam worden
            opgenomen.</assert>
    </rule>
    <title>Namen van organisaties en apparaten/systemen</title>
    <rule context="hl7:Organization/hl7:name | hl7:representedOrganization/hl7:name | hl7:device/hl7:name">
        <assert test="not(@use='L')">Use='L' attribuut is niet toegestaan bij namen van organisaties of apparaten.'</assert>
        <assert test="not(*)">Subelementen zijn niet toegestaan bij organisaties en apparaten.</assert>
        <report test="substring(normalize-space(.),1,1)='&quot;'">Het gebruik van aanhalingstekens aan het begin van een naam is
            waarschijnlijk onjuist.</report>
    </rule>
    
    <title>Identificaties</title>
    <rule context="*[@root='2.16.528.1.1007.3.1']">
        <assert test="matches(@extension,'^[0-9]{9}$')">UZI-nummer persoon moet 9 cijfers lang zijn</assert>

        <!-- Overwegen meer generieke code controles te gaan doen -->
        <let name="codeValue" value="../hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.111']/@code"/>
        <assert test="string-length($codeValue)=0 or document('../vocab/2.16.840.1.113883.2.4.15.111.xml')/*/hl7:code[@code=$codeValue]">UZI rolcode
            attribuut code bevat geen geldige RoleCodeNL.</assert>
    </rule>
    <rule context="*[@root='2.16.528.1.1007.3.2']">
        <assert test="matches(@extension,'^[0-9]{9}$')">UZI-nummer systeem moet 9 cijfers lang zijn</assert>
    </rule>
    <!-- 
        URA mag 1 zijn, indien het id van de entiteit waar de organisatie bij 
        hoort (bijvoorbeeld een AssignedDevice) het ZIM is.
    -->
    <rule context="*[@root='2.16.528.1.1007.3.3']">
        <assert
            test="(../../hl7:id/@root='2.16.840.1.113883.2.4.6.6' and ../../hl7:id/@extension='1' and @extension='1') or
            matches(@extension,'^[0-9]{8}$')"
            >UZI-registerabonneenummer moet 8 cijfers lang zijn</assert>

        <!-- Overwegen meer generieke code controles te gaan doen -->
        <let name="codeValue" value="../hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.1060']/@code"/>
        <assert test="string-length($codeValue)=0 or document('../vocab/2.16.840.1.113883.2.4.15.1060.xml')/*/hl7:code[@code=$codeValue]">Organisatie
            rolcode attribuut code bevat geen geldige AssignedRoleType.</assert>
    </rule>
    <rule context="*[@root='2.16.840.1.113883.2.4.6.1']">
        <assert test="matches(@extension,'^[0-9]{8}$')">AGB-code moet 8 cijfers lang zijn</assert>
    </rule>
    <rule context="*[@root='2.16.840.1.113883.2.4.6.3']">
        <assert test="matches(@extension,'^[0-9]{9}$')">Burgerservicenummer moet 9 cijfers lang zijn</assert>
        <assert
            test="(
            (   number(substring(@extension,1,1))*9 )+
            (   number(substring(@extension,2,1))*8 )+
            (   number(substring(@extension,3,1))*7 )+
            (   number(substring(@extension,4,1))*6 )+
            (   number(substring(@extension,5,1))*5 )+
            (   number(substring(@extension,6,1))*4 )+
            (   number(substring(@extension,7,1))*3 )+
            (   number(substring(@extension,8,1))*2 )+
            (   number(substring(@extension,9,1))*-1) ) mod 11=0"
            >Burgerservicenummer voldoet niet aan modulo 11 proef</assert>
    </rule>
    <rule context="*[@root='2.16.840.1.113883.1.6']">
        <let name="codeValue" value="@extension"/>
        <assert test="document(concat('../vocab/',@root,'.xml'))/*/hl7:code[@code=$codeValue]">Ongeldig interactie-id in attribuut extensie.</assert>
    </rule>
    <!-- 
        Issue 27375
        DICOM heeft een maximum van 64 tekens op een OID
        Canada hanteert 200 tekens op OID's
    -->
    <rule context="*[@root or @extension]">
        <report test="not(string-length(@root) &lt;= 64)">attribuut root is langer dan 64 tekens. Er is nog geen maximum gesteld, maar
            hier is wel naar gevraagd. Gaarne melden als deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein is</report>

        <report test="not(not(@extension) or string-length(@extension) &lt;= 64)">attribuut extension is langer dan 64 tekens. Er is nog geen maximum
            gesteld, maar hier is wel naar gevraagd. Gaarne melden als deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein
            is</report>
    </rule>
    <title>Status Codes</title>
    <!-- Uitzondering voor queryContinuation.statusCode -->
    <rule context="hl7:statusCode[not(ancestor::hl7:queryContinuation[1])]">
        <assert test="@nullFlavor or (@code and count(@*)=1)"
            >statusCode heeft datatype CS, welke alleen een nullFlavor of een attribuut code kan
            hebben</assert>

        <let name="codeValue" value="@code"/>
        <assert test="string-length($codeValue)=0 or 
            document('../vocab/2.16.840.1.113883.5.14.xml')/*/hl7:code[@code=$codeValue] or
            document('../vocab/2.16.840.1.113883.5.1068.xml')/*/hl7:code[@code=$codeValue]"
            >statusCode attribuut code bevat geen geldige ActStatus of RoleStatus.</assert>
        
        <report test="$codeValue='active' and ../hl7:effectiveTime/hl7:high/@value"
            >statusCode is 'active', maar er is een effectiveTime/high (einddatum)</report>
    </rule>
</pattern>
