<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT932000NL02">
    <title>A_MedicationCombinedOrder universal</title>
    <!-- TDJ 20101117: versie 02, want reeds in gebruik bij Hwg
        inhoudelijke verschillen met COCT_MT932000NL:
        * Prescription -> prescription
        * <confidentialityCode> mag herhalen
        * <author> is verplicht, maar...
        * <AssignedPerson> is nillable
        * <diagnosisEvent><code> is verplicht
        * <diagnosisEvent><text> is verdwenen
        * <MDR><statusCode> is optioneel geworden                       
        * <MAR><id> is optioneel geworden
        * <MAR><doseCheckQuantity> is toegevoegd
        * <MAR><approachSiteCode> heeft nu datatype CE - check
        * <MAR><obs.Ev.Criterion><code> heeft nu datatype CV - check
    -->
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:text">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:statusCode">
        <extends rule="CS"/>
        <!-- Onderstaande is alleen waar bij voorschriften -->
        <assert role="error" test="@code='active' or @code='completed' or @nullFlavor='UNK'"
            >COCT_MT932000NL02: <value-of select="local-name(..)"/>/statusCode/@code moet 'active', of 'completed' zijn, of @nullFlavor moet 'UNK' zijn</assert>
    </rule>
    <rule context="$element/hl7:confidentialityCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.25'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Confidentiality.htm"
            >COCT_MT932000NL02: vertrouwelijkheidscode moet komen uit codesysteem '2.16.840.1.113883.5.25'</assert>
    </rule>
    
    <rule context="$element/hl7:subject">
        <assert role="error" test="not(@typeCode) or @typeCode='SBJ'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#SBJ"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'SBJ' zijn</assert>
    </rule>
    
    <!-- subject -->
    <title>COCT_MT050000NL R_PatientNL universal</title>
    <rule context="$element/hl7:subject/hl7:Patient" subject="COCT_MT050000NL">
        <assert role="error" test="not(@classCode) or @classCode='PAT'"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'PAT' zijn</assert>
        <assert role="error" test="hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
            >COCT_MT932000NL02: er moet tenminste een burgerservicenummer zijn ter identificatie</assert>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:addr">
        <extends rule="AD"/>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:telecom">
        <extends rule="TEL"/>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='active'"
            >COCT_MT932000NL02: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:Person">
        <assert role="error" test="hl7:name"
            >COCT_MT932000NL02: patiëntnaam moet een waarde hebben</assert>
        <assert role="error" test="hl7:birthTime"
            >COCT_MT932000NL02: birthTime moet een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:Person/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.840.1.113883.2.4.6.3'"
            >COCT_MT932000NL02: als er een persoonsnummer wordt gebruikt moet dat het burgerservicenummer zijn</assert>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:Person/hl7:name">
        <extends rule="PN"/>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/AdministrativeGender.htm"
            >COCT_MT932000NL02: geslacht moet komen uit codesysteem '2.16.840.1.113883.5.1'</assert>
    </rule>
    <rule context="$element/hl7:subject/hl7:Patient/hl7:Person/hl7:birthTime">
        <extends rule="TS"/>
    </rule>
    
    
    <!-- author -->
    <rule context="$element/hl7:author">
        <assert role="error" test="not(@typeCode) or @typeCode='AUT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#AUT"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'AUT' zijn</assert>
        <assert role="error" test="hl7:time[@nullFlavor='UNK' or @value]"
            >COCT_MT932000NL02: moment van voorschrijven ontbreekt of nullFlavor is niet gelijk aan 'UNK'</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:time">
        <extends rule="TS"/>
        <let name="tsValue" value="@value"/>
        <let name="normTsValue" value="xs:integer(substring(concat(replace($tsValue,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <let name="creationTime" value="ancestor::hl7:*[hl7:creationTime][1]/hl7:creationTime/@value"/>
        <let name="normCreationTime" value="xs:integer(substring(concat(replace($creationTime,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <assert role="error"
            test="not(@value) or $normTsValue &lt;= $normCreationTime"
            >COCT_MT932000NL02: moment van voorschrijven '<value-of select="$tsValue"/>' moet liggen vóór
            t.o.v. het moment van verzenden van het bericht '<value-of select="$creationTime"/>'</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:modeCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1064'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationMode.htm"
            >COCT_MT932000NL02: participatiewijze moet komen uit codesysteem '2.16.840.1.113883.5.1064'</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:signatureCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.89'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/SignatureCode.htm"
            >COCT_MT932000NL02: participatiehandtekening moet komen uit codesysteem '2.16.840.1.113883.5.89'</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:signatureText">
        <extends rule="ED"/>
    </rule>
    
    <!-- assignedPerson-->
    <title>COCT_MT090102NL R_AssignedPerson identified/confirmable</title>
    <rule context="$element/hl7:author/hl7:AssignedPerson" subject="COCT_MT090102NL">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:AssignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >COCT_MT932000NL02: identificatie van de voorschrijver moet UZI of AGB zijn</assert>
        
        <let name="performerRoot" value="../../../hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:id/@root"/>
        <let name="performerExt" value="../../../hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:id/@extension"/>
        <report role="warning" test="@root=$performerRoot and @extension=$performerExt"
            >COCT_MT932000NL02: medicationDispenseRequest/performer en presciption/author zijn gelijk. Alleen een apotheekhoudend huisarts mag zowel voorschrijven als afleveren.</report>
    </rule>
    <rule context="$element/hl7:author/hl7:AssignedPerson/hl7:code">
        <extends rule="CE"/>
    </rule>
    
    <rule context="$element/hl7:directTarget">
        <assert role="error" test="not(@typeCode) or @typeCode='DIR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#DIR"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'DIR' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication">
        <assert role="error" test="not(@classCode) or @classCode='THER'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#THER"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'THER' zijn</assert>
    </rule>
    
    <title>E_MedicationKind universal</title>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'MMAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT932000NL02/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.1' or @codeSystem='2.16.840.1.113883.2.4.4.10' or
            @codeSystem='2.16.840.1.113883.2.4.4.7' or @codeSystem='2.16.840.1.113883.2.4.4.8'"
            >COCT_MT932000NL02/COCT_MT720000NL: medicatiecode moet komen uit codesysteem GPK, PRK, HPK, of ZI_Nummer</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.8' and 
            (hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.1' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.10' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.7'))"
            >COCT_MT932000NL02/COCT_MT720000NL: medicatiecode uit ZI_Nummer kan niet een translation hebben uit een minder specifiek codesysteem</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.7' and 
            (hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.1' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.10'))"
            >COCT_MT932000NL02/COCT_MT720000NL: medicatiecode uit HPK kan niet een translation hebben uit een minder specifiek codesysteem</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.70' and 
            hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.1')"
            >COCT_MT932000NL02/COCT_MT720000NL: medicatiecode uit PRK kan niet een translation hebben uit een minder specifiek codesysteem</assert>
        <assert role="error" test="(@code and @displayName) or not(@code)"
            >COCT_MT932000NL02/COCT_MT720000NL: medicatiecode moet attribuut @displayName hebben tenzij er geen code is</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:desc">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:formCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.11'"
            >COCT_MT932000NL02/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.11' (G-Standaard subtabel 0006 farmaceutische vormen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.85'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/OrderableDrugForm.htm"
            >COCT_MT932000NL02/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.85'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:lotNumberText">
        <extends rule="ST"/>
    </rule>
    
    <!-- activeIngredient -->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:activeIngredient">
        <report role="warning" test="."
            >COCT_MT932000NL02/COCT_MT720000NL: activeIngredient nog niet gebruiken.</report>
        <assert role="error" test="not(@classCode) or @classCode='ACTI'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ACTI"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'ACTI' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:activeIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- hl7:activeIngredient/hl7:activeIngredientMaterialKind en hl7:otherIngredient/hl7:otherIngredientMaterialKind -->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ACTI"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'MAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT932000NL02/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:code">
        <extends rule="CE"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:desc">
        <extends rule="ED"/>
    </rule>
    
    <!-- content -->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#CONT"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT932000NL02/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='1.3.160'"
            >COCT_MT932000NL02/COCT_MT720000NL: verpakkingscode moet komen uit codesysteem '1.3.160' (EAN-artikelcodes)</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:formCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.12'"
            >COCT_MT932000NL02/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.12' (G-Standaard subtabel 0004 omschrijving deelverpakkingen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.1060'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ContainerEntityType.htm"
            >COCT_MT932000NL02/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.1060'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:asSubContent">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:asSubContent/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    
    <!-- otherIngredient -->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:otherIngredient">
        <assert role="error" test="not(@classCode) or @classCode='INGR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#INGR"
            >COCT_MT932000NL02/COCT_MT720000NL: @classCode moet indien aanwezig 'INGR' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:MedicationKind/hl7:otherIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- see activeIngredient for MaterialKind -->
    
    <!-- 
        productOf
    -->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf">
        <assert role="error" test="not(@typeCode) or @typeCode='PRD'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRD"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'PRD' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:substitutionCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1071'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/SubstitutionCondition.htm"
            >COCT_MT932000NL02: vervangingscode moet komen uit codesysteem '2.16.840.1.113883.5.1071'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest">
        <assert role="error" test="not(@classCode) or @classCode='SPLY'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SPLY"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'SPLY' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'RQO' zijn</assert>
        <!-- assert aangepast, optie met effectiveTime met alleen een IVL_TS toegevoegd -->
<!-- Regels met betrekking tot expectedUse Time uitgecommentarieerd, moet nog aangepast aan AORTA 7        -->
<!--        <assert role="error" test="hl7:expectedUseTime/hl7:low/@value or 
            ../../hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime/hl7:comp[@xsi:type='IVL_TS'][string-length(hl7:low/@value)&gt;=12 and string-length(hl7:high/@value)&gt;=12]
            or ../../hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='IVL_TS'][string-length(hl7:low/@value)&gt;=12 and string-length(hl7:high/@value)&gt;=12]"
            >COCT_MT932000NL02: expectedUseTime/low moet aanwezig zijn, of medicationadministrationRequest/effectiveTime moet een interval
            bevatten met zowel low als high tot op de minuut nauwkeurig.</assert>
--><!--        <assert role="error" test="not(hl7:expectedUseTime and hl7:effectiveTime) or hl7:expectedUseTime/hl7:low/@value >= hl7:effectiveTime/@value"
            >COCT_MT932000NL02: expectedUseTime/low is niet groter of gelijk aan effectiveTime</assert>-->
        
        <let name="performerIdRoot" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root"/>
        <let name="performerIdExtension" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension"/>
        <let name="responsiblePartyIdRoot" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root"/>
        <let name="responsiblePartyIdExt" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension"/>
        <assert role="error" test="not(hl7:performer and hl7:responsibleParty) or 
            ($performerIdRoot=$responsiblePartyIdRoot and $performerIdExtension=$responsiblePartyIdExt)"
            >COCT_MT932000NL02: performer en responsibleParty hebben verschillende organisaties</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:statusCode">
        <extends rule="CS"/>
        <!-- Onderstaande is alleen waar bij voorschriften -->
        <assert role="error" test="@code='active'"
            >COCT_MT932000NL02: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:repeatNumber">
        <extends rule="IVL_INT"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:quantity">
        <extends rule="PQ"/>
        <assert role="error" test="@nullFlavor='NA' or not(*//hl7:translation) or
            *//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' or @codeSystem='2.16.840.1.113883.2.4.4.12']"
            >COCT_MT932000NL02: quantity moet een vertaling hebben op basis van een numerieke code uit '2.16.840.1.113883.2.4.4.1.900.2' 
            (G-Standaard basiseenheden tabel 2) of '2.16.840.1.113883.2.4.4.12' (G-Standaard deelverpakkingen tabel 4)</assert>
        <assert role="error" test="@nullFlavor='NA' or @value > 0"
            >COCT_MT932000NL02: quantity moet groter zijn 0 of @nullFlavor moet "NA" zijn</assert>
        <report role="warning" test="hl7:translation and not(hl7:translation[@value=../@value])"
            >COCT_MT932000NL02: quantity in translation moet gelijk zijn aan UCUM quantity</report>
        <assert role="error" test="not(hl7:translation) or hl7:translation[@code and @displayName]"
            >COCT_MT932000NL02: quantity in translation mist displayName bij code</assert>
    </rule>
<!--    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:expectedUseTime">
        <extends rule="IVL_TS"/>
        <report role="warning" test="not(hl7:high or ../../../hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:precondition)"
            >COCT_MT932000NL02: expectedUseTime/high element ontbreekt en er is geen medicationAdministrationRequest/precondition.</report>
    </rule>-->
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:destination">
        <assert role="error" test="not(@typeCode) or @typeCode='DST'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#DST"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'DST' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:destination/hl7:serviceDeliveryLocation">
        <assert role="error" test="not(@classCode) or @classCode='SDLOC'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#SDLOC"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'SDLOC' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:destination/hl7:serviceDeliveryLocation/hl7:code">
        <extends rule="CV"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:destination/hl7:serviceDeliveryLocation/hl7:addr">
        <extends rule="AD"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer">
        <assert role="error" test="not(@typeCode) or @typeCode='PRF'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRF"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'PRF' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ASSIGNED"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >COCT_MT932000NL02: identificatie van de beoogde verstrekker moet UZI of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:representedOrganization">
        <assert role="error" test="not(@classCode) or @classCode='ORG'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ORG"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'ORG' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#INSTANCE"
            >COCT_MT932000NL02: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.3' or @root='2.16.840.1.113883.2.4.6.1'"
            >COCT_MT932000NL02: identificatie van de organisatie van de beoogde voorschrijver moet URA of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:name">
        <extends rule="ON"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:productOf/hl7:medicationDispenseRequest/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:addr">
        <extends rule="AD"/>
    </rule>
    
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf">
        <assert role="error" test="not(@typeCode) or @typeCode='TPA'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#TPA"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'TPA' zijn</assert>
    </rule>
    
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:text">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:statusCode">
        <extends rule="CS"/>
        <!-- Onderstaande is alleen waar bij voorschriften -->
        <assert role="error" test="@code='active'"
            >COCT_MT932000NL02: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='SXPR_TS']">
        <extends rule="SXPR_TS"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='PIVL_TS']">
        <extends rule="PIVL_TS"/>
        <assert role="error" test="hl7:period/@value > 0"
            >COCT_MT932000NL02: als effectiveTime van het type PIVL_TS is, moet de periode groter dan 0 zijn</assert>
        <assert role="error" test="hl7:period/@value and hl7:period/@unit"
            >COCT_MT932000NL02: als effectiveTime van het type PIVL_TS is, moeten @value en @unit een waarde hebben period</assert>
        <assert role="error" test="hl7:period[@unit='h' or @unit='d' or @unit='wk' or @unit='mo' or @unit='a']"
            >COCT_MT932000NL02: effectiveTime is van het type PIVL_TS, maar de period unit is niet 'h', 'd', 'wk', 'mo' of 'a'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='IVL_TS']">
        <extends rule="IVL_TS"/>
        <assert role="error" test="hl7:low/@value and hl7:high/@value"
            >COCT_MT932000NL02: als effectiveTime van het type IVL_TS is, moeten low en high beiden een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:priorityCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.7'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Priority.htm"
            >COCT_MT932000NL02: prioriteit moet komen uit codesysteem '2.16.840.1.113883.5.7'</assert>
        <assert role="error" test="not(@code) or (@code='R' or @code='UR')" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Priority.htm"
            >COCT_MT932000NL02: prioriteit moet @code 'R' or 'UR' hebben</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:routeCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.9'"
            >COCT_MT932000NL02: toedieningsweg moet komen uit codesysteem '2.16.840.1.113883.2.4.4.9' (G-standaard thesaurus subtabel 0007)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation[@codeSystem='2.16.840.1.113883.5.112']" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RouteOfAdministration.htm"
            >COCT_MT932000NL02: toedieningsweg mag een vertaling hebben en moet dan komen uit '2.16.840.1.113883.5.112'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:approachSiteCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1052'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActSite.htm"
            >COCT_MT932000NL02: toedieningsplaats moet komen uit codesysteem '2.16.840.1.113883.5.1052'</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:doseQuantity">
        <extends rule="IVL_PQ"/>
        <assert role="error" test="not(*//hl7:translation/@codeSystem) or 
            *//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' or @codeSystem='2.16.840.1.113883.2.4.4.1.361']"
            >COCT_MT932000NL02: doseerhoeveelheid mag een vertaling hebben en moet dan een numerieke code zijn uit '2.16.840.1.113883.2.4.4.1.900.2' 
            (G-Standaard basiseenheden tabel 2) of '2.16.840.1.113883.2.4.4.1.361' (NHG Tabel 25)</assert>
        <assert role="error" test="not(*//hl7:translation/@codeSystem) or *//hl7:translation/@displayName"
            >COCT_MT932000NL02: in translation elementen moet @displayName een waarde hebben als er een code is</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2']) or 
            *//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' and @value=../@value]"
            >COCT_MT932000NL02: translation/@value in G-Standaard basiseenheden tabel 2 moet gelijk zijn aan doseQuantity/@value</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='10' and not(@value=../@value div 15)])"
            >COCT_MT932000NL02: NHG Tabel 25 code is '10', maar value in Tabel 25 vertaling is niet gelijk aan doseQuantity/@value / 15</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='11' and not(@value=../@value div 8)])"
            >COCT_MT932000NL02: als NHG Tabel 25 code '11' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 8</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='14' and not(@value=../@value div 3)])"
            >COCT_MT932000NL02: NHG Tabel 25 code is '14', maar value in Tabel 25 vertaling is niet gelijk aan doseQuantity/@value / 3</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:rateQuantity">
        <extends rule="IVL_PQ"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:doseCheckQuantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:maxDoseQuantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support2">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support2/hl7:medicationAdministrationInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support2/hl7:medicationAdministrationInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT932000NL02: toedieningsinstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:precondition">
        <assert role="error" test="not(@typeCode) or @typeCode='PRCN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#PRCN"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'PRCN' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:pauseQuantity">
        <extends rule="PQ"/>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:observationEventCriterion">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN.CRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN.CRT"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'EVN.CRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:observationEventCriterion/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT932000NL02: preconditie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support1">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support1/hl7:medicationStorageInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:directTarget/hl7:prescribedMedication/hl7:therapeuticAgentOf/hl7:support1/hl7:medicationStorageInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT932000NL02: opslaginstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    
    <!-- predecessor -->
    <rule context="$element/hl7:predecessor">
        <assert role="error" test="not(@typeCode) or @typeCode='PREV'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#PREV"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'PREV' zijn</assert>
    </rule>
    <rule context="$element/hl7:predecessor/hl7:previousPrescription">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    <rule context="$element/hl7:predecessor/hl7:previousPrescription/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:predecessor/hl7:previousPrescription/hl7:statusCode">
        <extends rule="CV"/>
    </rule>
    
    <!-- reason -->
    <rule context="$element/hl7:reason">
        <assert role="error" test="not(@typeCode) or @typeCode='RSON'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#RSON"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'RSON' zijn</assert>
    </rule>
    <rule context="$element/hl7:reason/hl7:diagnosisEvent">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    <rule context="$element/hl7:reason/hl7:diagnosisEvent/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:reason/hl7:diagnosisEvent/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="@code='DX' and @codeSystem='2.16.840.1.113883.5.4'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActCode.htm#DX"
            >COCT_MT932000NL02: @code moet 'DX' zijn en @codeSystem '2.16.840.1.113883.5.4'</assert>
    </rule>
    <!--rule context="$element/hl7:reason/hl7:diagnosisEvent/hl7:text">
        <extends rule="ST"/>
    </rule-->
    <rule context="$element/hl7:reason/hl7:diagnosisEvent/hl7:value">
        <extends rule="CE"/>
    </rule>
    
    <!-- reference -->
    <rule context="$element/hl7:reference">
        <assert role="error" test="not(@typeCode) or @typeCode='REFR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#REFR"
            >COCT_MT932000NL02: @typeCode moet indien aanwezig 'REFR' zijn</assert>
    </rule>
    <rule context="$element/hl7:reference/hl7:patientCareProvision">
        <assert role="error" test="not(@classCode) or @classCode='REFR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#PCPR"
            >COCT_MT932000NL02: @classCode moet indien aanwezig 'PCPR' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >COCT_MT932000NL02: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    <rule context="$element/hl7:reference/hl7:patientCareProvision/hl7:id">
        <extends rule="II"/>
    </rule>
</pattern>
