<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van REPC_IN990004NL - CHP Primary Care EHR Extract</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>

    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>

    <!--pattern is-a="attentionLine" id="REPC_IN990004NL-attentionLine">
        <param name="messagePatientId"
            value="hl7:ControlActProcess/hl7:subject/hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"/>
        <param name="attentionLineOptional" value="'true'"/>
    </pattern-->
    
    <pattern is-a="transmission-wrapper" id="REPC_IN990004NL-wrapper">
        <param name="element" value="hl7:REPC_IN990004NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="REPC_IN990004NL-controlAct">
        <param name="element" value="hl7:REPC_IN990004NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:REPC_IN990004NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:REPC_IN990004NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='NE'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'NE'.</assert>
        </rule>
        <rule context="hl7:REPC_IN990004NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <!-- text attributen -->
    <pattern>
        <title>text attributen moeten vrije tekst bevatten</title>
        <rule context="hl7:PrimaryCareProvision//hl7:text">
            <extends rule="ED"/>
            <assert role="error" test="not(@mediaType) or @mediaType='text/plain'"
                ><name path=".."/>/<name/> mag alleen als vrije tekst (mediaType='text/plain') worden gebruikt. Andere waarden zijn niet toegestaan</assert>
            <assert role="error" test="not(@representation) or @representation='TXT'"
                ><name path=".."/>/<name/> mag alleen als vrije tekst (representation='TXT') worden gebruikt. Andere waarden zijn niet toegestaan</assert>
            <assert role="error" test="not(@integrityCheck or @integrityCheckAlgorithm or @updateMode)"
                ><name path=".."/>/<name/> mag alleen attributen xsi:type, mediaType, representation, of language hebben</assert>
            <assert role="error" test="not(child::*)"
                ><name path=".."/>/<name/> mag geen elementen bevatten</assert>
        </rule>
    </pattern>

    <!-- ControlAct Wrapper -->
    <pattern>
        <title>ControlAct Wrapper</title>
        <rule context="hl7:ControlActProcess">
            <assert role="error" test="@moodCode='EVN'"
                >moodCode is niet gelijk aan EVN</assert>
            <assert role="error" test="hl7:authorOrPerformer/@typeCode='AUT'"
                >typecode authorOrPerformer is niet gelijk aan AUT</assert>
        </rule>
        <rule context="hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice">
            <assert role="error" test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.6'])=1"
                >In een PS moet in de AssignedDevice de landelijke applicatie Id zijn opgenomen.</assert>
        </rule>
    </pattern>

    <!-- Patient en Arts -->
    <pattern>
        <title>Patientgegevens</title>
        <rule context="hl7:PrimaryCareProvision/hl7:subject">
            <assert role="error" test="not(@contextControlCode) or @contextControlCode='AP'"
                >contextControlCode is niet gelijk aan AP</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="../hl7:id[@root='2.16.840.1.113883.2.4.6.3' and @extension] or @nullFlavor"
                >id moet tenminste een BSN ('2.16.840.1.113883.2.4.6.3') bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='terminated'"
                >statusCode is niet gelijk aan 'active' of 'terminated'</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:birthTime">
            <extends rule="TS"/>
            <assert role="error" test="@value"
                >Geboortedatum ontbreekt</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:deceasedInd">
            <extends rule="BL"/>
            <assert role="error" test="not(. and hl7:Patient/hl7:deceasedTime/@value)"
                >deceasedInd alleen gebruiken indien overlijdensdatum onbekend is</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:subject/hl7:scopedContactParty">
            <assert role="error" test="@classCode='PAYOR'"
                >@classCode van scopedContactParty moet 'PAYOR' zijn</assert>
            <assert role="error" test="hl7:Person/hl7:name"
                >scopedContactParty/Person/name ontbreekt</assert>
        </rule>
    </pattern>

    <!-- PrimaryCareProvision Act -->
    <pattern>
        <title>PrimaryCareProvision Act</title>
        <rule context="hl7:PrimaryCareProvision/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                >statusCode is niet gelijk aan active of completed</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value or @nullFlavor='UNK'"
                >Startdatum is niet aangegeven, of nullFlavor is niet 'UNK'</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:text">
            <extends rule="ST"/>
            <report role="warning" test="hl7:text"
                >text element heeft een waarde. Het komt zelden voor dat hier iets in zou kunnen staan dat niet eigenlijk
                thuishoort in een ander deel, zoals een attentieregel, of een journaalregel.</report>
        </rule>
    </pattern>
    <!-- Acts direct gekoppeld aan PrimaryCareProvision -->
    <pattern>
        <title>Voorgeschiedenis</title>
        <rule context="hl7:PrimaryCareProvision/hl7:predecessor">
            <assert role="error" test="not(hl7:priorPrimaryCareProvision/hl7:predecessor)"
                >De voorgeschiedenis mag zelf geen voorgeschiedenis hebben</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Episodes, EpisodeOfCondition deel</title>
        <rule context="hl7:episodeOfCondition/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:episodeOfCondition/hl7:text">
            <extends rule="ST"/>
            <assert role="error" test="string-length(.)>0"
                >Episode bevat geen tekst</assert>
        </rule>
        <rule context="hl7:episodeOfCondition/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                >statusCode is niet gelijk aan active of completed</assert>
        </rule>
        <rule context="hl7:episodeOfCondition/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:episodeOfCondition">
            <assert role="error" test="not(hl7:component1/hl7:episodeOfCondition/hl7:component1)"
                >Episodes mogen slechts 1 niveau diep genest worden</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Episodes, EpisodOfCare deel</title>
        <rule context="hl7:episodOfCare/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:episodOfCare/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                >statusCode is niet gelijk aan active of completed</assert>
        </rule>
        <rule context="hl7:episodOfCare/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:episodOfCare/hl7:component/hl7:actReference/hl7:id">
            <extends rule="II"/>
            <let name="actRefRoot" value="@root"/>
            <let name="actRefExt" value="@extension"/>
            <assert role="error"
                test="../../../../../../../hl7:component1/hl7:encounter/hl7:component/*/hl7:id[@root=$actRefRoot and @extension=$actRefExt] or
                ../../../../../../../hl7:component2/*/hl7:id[@root=$actRefRoot and @extension=$actRefExt]"
                >actReference/id verwijst niet naar een activiteit in deze interactie onder component1 of component2</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Consulten</title>
        <rule context="hl7:encounter/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                >Id element mist root of extension</assert>
        </rule>
        <rule context="hl7:encounter/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:encounter/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@code or @nullFlavor='UNK' or @nullFlavor='OTH'"
                >Er moet een code attrbituut zijn of een nullFlavor attribuut met de waarde 'UNK' of 'OTH'.</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.14' or @nullFlavor"
                >De codesystem OID moet naar NHG tabel 14 wijzen of er moet een nullFlavor attribuut zijn.</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0 or @nullFlavor"
                >Het displayName attribuut moet gevuld zijn of er moet een nullFlavor attribuut zijn.</assert>
        </rule>
    	<rule context="hl7:encounter/hl7:component">
    		<report role="warning" test="not(hl7:sequenceNumber)"
    		    >Component bevat geen sequenceNumber</report>
    	</rule>
    </pattern>
    <pattern>
        <title>Attentieregels</title>
        <rule context="hl7:pertinentAnnotationObsEvent/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="(@code='ATT' or @code='SOC' or @code='SOS' or @code='WNN') and @codeSystem='2.16.840.1.113883.5.4'"
                >code attribuut in code is niet gelijk aan ATT, SOC, SOS of WNN, of codeSystem is niet gelijk aan 2.16.840.1.113883.5.4</assert>
        </rule>
        <rule context="hl7:pertinentAnnotationObsEvent">
            <assert role="error" test="string-length(normalize-space(hl7:text/text()[1]))>0"
                >Attentieregel bevat geen tekst</assert>
        </rule>
    </pattern>
    <!-- CMETs direct gekoppeld aan PrimaryCareProvision -->
    <pattern>
        <title>Allergieen en Ongewenste Groepen</title>
        <rule context="hl7:ObservationIntolerance">
            <assert role="error" test="@negationInd"
                >negationInd ontbreekt</assert>
        </rule>
        <rule context="hl7:ObservationIntolerance/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:ObservationIntolerance/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@code='INTLRNC' and @codeSystem='2.16.840.1.113883.5.4'"
                >code attribuut in code is niet INTLRNC en/of codeSystem is niet '2.16.840.1.113883.5.4'</assert>
        </rule>
        <rule context="hl7:ObservationIntolerance/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code and @code='completed'"
                >statusCode is niet gelijk aan completed</assert>
        </rule>
        <rule context="hl7:ObservationIntolerance/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:ObservationIntolerance/hl7:value">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >value/@code ontbreekt</assert>
            <assert role="error"
                test="@codeSystem='2.16.840.1.113883.2.4.4.1.902.122' or
                @codeSystem='2.16.840.1.113883.2.4.4.1.725' or
                @codeSystem='2.16.840.1.113883.2.4.4.1.750' or
                @codeSystem='2.16.840.1.113883.2.4.4.7'"
                >value/@codeSystem moet zijn '2.16.840.1.113883.2.4.4.1.902.122' (Ongewenste Groepen), '2.16.840.1.113883.2.4.4.1.725' (Individuele
                bestanddelen, oftewel stoffen op basis van stofnaamcode (SNK)), '2.16.840.1.113883.2.4.4.1.750' (Individuele bestanddelen in
                combinatie met een toedieningsweg (SSK)), of '2.16.840.1.113883.2.4.4.7' (Ongewenst Handelsprodukt (HPK)) </assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >@displayName attribuut in value is niet gevuld</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Contra-Indicaties</title>
        <rule context="hl7:ContraIndication/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:ContraIndication/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="(@code='CI' or @code='DERCI') and @codeSystem='2.16.840.1.113883.5.4'"
                >code/@code moet 'CI' of 'DERCI' zijn en komen uit '2.16.840.1.113883.5.4'</assert>
        </rule>
        <rule context="hl7:ContraIndication/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:ContraIndication/hl7:value">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >value/@code ontbreekt</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.1.902.40' or @codeSystem='2.16.840.1.113883.2.4.4.31.1'"
                >value/@codeSystem moet zijn '2.16.840.1.113883.2.4.4.1.902.40' (G-standaard thesaurus 40) of '2.16.840.1.113883.2.4.4.31.1' (ICPC-1-2000NL)</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >displayName attribuut in value is niet gevuld</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Familie anamnese</title>
        <rule context="hl7:Observation/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:Observation/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="@code='FAMILYHISTORY' and @codeSystem='2.16.840.1.113883.5.4'"
                >code/@code moet 'FAMILYHISTORY' zijn en @codeSystem '2.16.840.1.113883.5.4'</assert>
        </rule>
        <rule context="hl7:Observation">
            <assert role="error" test="string-length(normalize-space(hl7:text)) &gt; 0"
                >text ontbreekt</assert>
        </rule>
        <rule context="hl7:Observation/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Ruiters</title>
        <rule context="hl7:Marker/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                >Id element mist root of extension, of er is geen nullFlavor</assert>
        </rule>
        <rule context="hl7:Marker/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="@code='RUITER' and @codeSystem='2.16.840.1.113883.5.4'"
                >code attribuut in code is niet RUITER en/of codeSystem is niet '2.16.840.1.113883.5.4'</assert>
        </rule>
        <rule context="hl7:Marker/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                >Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:Marker/hl7:value">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >value/@code ontbreekt</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.16'"
                >value/@code moet zijn '2.16.840.1.113883.2.4.4.30.16' (NHG tabel 16, Ruiters)</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >value/@displayName ontbreekt</assert>
        </rule>
    </pattern>
    <!-- CMETs in Activities ChoiceBox -->
    <pattern>
        <title>Journaalregels</title>
        <rule context="hl7:JournalEntry/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                >Id element mist root of extension attribuut</assert>
        </rule>
        <rule context="hl7:JournalEntry/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="(@code='S' or @code='O' or @code='E' or @code='P') and 
                @codeSystem='2.16.840.1.113883.2.4.4.32.2'"
                >code attribuut in code is niet S, O, E of P en/of codeSystem is niet '2.16.840.1.113883.2.4.4.32.2'</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >code/@displayName ontbreekt</assert>
        </rule>
        <rule context="hl7:JournalEntry">
            <assert role="error" test="ancestor::hl7:encounter or hl7:effectiveTime/@value"
                >effectiveTime ontbreekt en de journaalregel is geen onderdeel van een consult</assert>
            <assert role="error" test="string-length(normalize-space(hl7:value/text()[1])) &gt; 0"
                >Journaalregel bevat geen tekst</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Diagnoses</title>
        <rule context="hl7:ControlActProcess/hl7:subject//hl7:ObservationDx/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                >Id element mist root of extension attribuut</assert>
        </rule>
        <rule context="hl7:ObservationDx/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="(@code='DISDX' or @code='ADMDX') and @codeSystem='2.16.840.1.113883.5.4'"
                >code attribuut in code is niet DISDX of ADMDX en/of codeSystem is niet '2.16.840.1.113883.5.4'</assert>
            <assert role="error" test="not(@code='ADMDX') or
                (@code='ADMDX' and ../hl7:author/hl7:Patient/hl7:id[@root and @extension])"
                >Diagnosecode is 'ADMDX', maar de patiënt ontbreekt als auteur</assert>
            <assert role="error" test="not(@code='DISDX') or
                (@code='DISDX' and not(../hl7:author/hl7:Patient))"
                >Diagnosecode is 'DISDX', maar er is een patiënt als auteur </assert>
        </rule>
        <rule context="hl7:ObservationDx">
            <assert role="error" test="ancestor::hl7:encounter or ancestor::hl7:episodeOfCondition or
                hl7:effectiveTime/hl7:low/@value"
                >effectiveTime (startdatum) ontbreekt en de diagnose is geen onderdeel van een consult of episode</assert>
        </rule>
        <rule context="hl7:ObservationDx/hl7:value">
            <extends rule="CE"/>
            <assert role="error"
                test="@code and @codeSystem='2.16.840.1.113883.2.4.4.31.1' and
                string-length(normalize-space(@displayName)) &gt; 0"
                >value moet een attribuut code hebben uit codeSystem ICPC-1-2000 (OID: 2.16.840.1.113883.2.4.4.31.1) en het attribuut displayName moet
                een waarde hebben</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Verwijzingen</title>
        <rule context="hl7:PatientCareProvisionRequest/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                >Id element mist root of extension attribuut</assert>
        </rule>
        <rule context="hl7:PatientCareProvisionRequest/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='completed'"
                >statusCode is niet gelijk aan completed</assert>
        </rule>
        <rule context="hl7:PatientCareProvisionRequest">
            <assert role="error" test="ancestor::hl7:encounter or
                hl7:effectiveTime/hl7:low/@value">de effectiveTime (startdatum) ontbreekt en de
                verwijzing is geen onderdeel van een consult</assert>
        </rule>
        <rule context="hl7:PatientCareProvisionRequest/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >code/@code ontbreekt</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.12'"
                >code/@codeSystem moet zijn NHG tabel 12</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >code/@displayName ontbreekt</assert>
        </rule>
        <rule context="hl7:PatientCareProvisionRequest">
            <assert role="error" test="hl7:performer/hl7:AssignedEntity/hl7:id[@root and @extension]"
                >De performer is niet geïdentificeerd</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Therapie</title>
        <rule context="hl7:ProcedureEvent/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                >Id element mist root of extension attribuut</assert>
        </rule>
        <rule context="hl7:ProcedureEvent/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='completed'"
                >statusCode is niet gelijk aan completed</assert>
        </rule>
        <rule context="hl7:ProcedureEvent">
            <assert role="error" test="ancestor::hl7:encounter or
                hl7:effectiveTime/hl7:low/@value"
                >de effectiveTime (startdatum) ontbreekt en de verwijzing is geen onderdeel van een consult</assert>
        </rule>
        <rule context="hl7:ProcedureEvent/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >code/@code ontbreekt</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.31.1'"
                >code/@codeSystem moet zijn ICPC-1-2000NL</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0"
                >code/@displayName ontbreekt</assert>
        </rule>
    </pattern>
    <!-- Medicatievoorschriften -->
    <pattern>
        <title>Medicatievoorschriften</title>
        <rule context="hl7:Prescription">
            <assert role="error" test="hl7:author/hl7:time/@value"
                >Datum voorschrift ontbreekt</assert>
        </rule>
    </pattern>
    <!-- Rest -->
    <pattern>
        <title>Gebruik G-Standaard codes</title>
        <rule context="hl7:MedicationKind/hl7:code">
            <extends rule="CE"/>
            <assert role="error"
                test="@codeSystem='2.16.840.1.113883.2.4.4.1' or
                @codeSystem='2.16.840.1.113883.2.4.4.10' or
                @codeSystem='2.16.840.1.113883.2.4.4.7' or
                @codeSystem='2.16.840.1.113883.2.4.4.8' or @nullFlavor='OTH'"
                >codeSystem moet een GPK, HPK, PRK of ZI nummer zijn of er moet een nullFlavor=OTH zijn.</assert>
        </rule>
    </pattern>
</schema>
