<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT120100NL">
    <title>Diagnose</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='OBS'"
            >COCT_MT120100NL: @classCode moet, indien anwezig, 'OBS' bevatten</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
            >COCT_MT120100NL: @moodCode moet, indien anwezig, 'EVN' bevatten</assert>
    </rule>
    <rule context="$element/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root and @extension"
            >COCT_MT120100NL: id element mist root of extension attribuut</assert>
    </rule>
    <rule context="$element/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="@code='DISDX' or @code='ADMDX'"
            >COCT_MT120100NL: @code moet 'DISDX' of 'ADMDX' bevatten</assert>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.5.4'"
            >COCT_MT120100NL: @codeSystem moet '2.16.840.1.113883.5.4' bevatten</assert>
        <assert role="error" test="not(@code='ADMDX') or
            (@code='ADMDX' and ../hl7:author/hl7:Patient/hl7:id[@root and @extension])"
            >COCT_MT120100NL: Diagnosecode is 'ADMDX', maar de patiënt ontbreekt als auteur</assert>
        <assert role="error" test="not(@code='DISDX') or
            (@code='DISDX' and not(../hl7:author/hl7:Patient))"
            >COCT_MT120100NL: Diagnosecode is 'DISDX', maar er is een patiënt als auteur</assert>
    </rule>
    <rule context="$element/hl7:text">
        <extends rule="ST"/>
    </rule>
    <rule context="$element/hl7:effectiveTime">
        <extends rule="IVL_TS"/>
        <assert role="error" test="hl7:low"
            >COCT_MT120100NL: low moet de datum en indien bekend de tijd bevatten van de start van de diagnose</assert>
        <assert role="error" test="not(@value or hl7:center or hl7:width)"
            >COCT_MT120100NL: alleen low en optioneel high mogen worden gebruikt</assert>
    </rule>
    <rule context="$element/hl7:uncertaintyCode">
        <extends rule="CD"/>
        <assert role="error" test="@code='U' and @codeSystem='2.16.840.1.113883.5.1053'"
            >COCT_MT120100NL: @code moet 'U' en @codeSystem moet '2.16.840.1.113883.5.1053' (ActUncertainty) bevatten</assert>
    </rule>
    <rule context="$element/hl7:value">
        <extends rule="CE"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.31.1'"
            >COCT_MT120100NL: @codeSystem moet '2.16.840.1.113883.2.4.4.31.1' (ICPC-1-200NL) bevatten</assert>
        <assert test="string-length(normalize-space(@displayName)) &gt; 0"
            >COCT_MT120100NL: @displayName is verplicht</assert>
    </rule>
    
    <rule context="$element/hl7:author">
        <assert role="error" test="not(@typeCode) or  @typeCode='AUT'"
            >COCT_MT120100NL: @typeCode moet, indien anwezig, 'AUT' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >COCT_MT120100NL: @contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:time">
        <extends rule="TS"/>
    </rule>
        
    <rule context="$element/hl7:performer">
        <assert role="error" test="not(@typeCode) or  @typeCode='PRF'"
            >COCT_MT120100NL: @typeCode moet, indien anwezig, 'PRF' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >COCT_MT120100NL: @contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    
    <rule context="$element/hl7:dataEnterer">
        <assert role="error" test="not(@typeCode) or  @typeCode='ENT'"
            >COCT_MT120100NL: @typeCode moet, indien anwezig, 'ENT' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >COCT_MT120100NL: @contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    <rule context="$element/hl7:dataEnterer/hl7:time">
        <extends rule="TS"/>
    </rule>
    
    <rule context="$element/hl7:subject">
        <assert role="error" test="not(@typeCode) or  @typeCode='SBJ'"
            >COCT_MT120100NL: @typeCode moet, indien anwezig, 'SBJ' bevatten</assert>
    </rule>
</pattern>