<?xml version="1.0" encoding="UTF-8"?>
<!--
    cda2_to_cdar3.xsl
    Copyright (C) 2012 Alexander-Henket
    
    This program is free software; you can redistribute it and/or modify it under the terms 
    of the GNU General Public License as published by the Free Software Foundation; 
    either version 3 of the License, or (at your option) any later version.
    
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
    without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.
    
    See http://www.gnu.org/licenses/gpl.html
-->
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                exclude-result-prefixes="xs xsi xd hl7 xsl"
                version="2.0">
   <xd:doc scope="stylesheet">
      <xd:desc>
         <xd:p>
            <xd:b>Created on:</xd:b>October 14, 2012</xd:p>
         <xd:p>
            <xd:b>Author:</xd:b> Alexander Henket, E.Novation</xd:p>
         <xd:p>
            <xd:b>Email:</xd:b> alexander.henket(a)enovation.nl</xd:p>
         <xd:p>Maps any CDA release 2 to CDA release 3 based on September 2012 Ballot, picks up any contents in other namespaces, 
                            and places that content to the end of the element if was found in. It is not possible to keep elements from other namespaces in between hl7 elements.</xd:p>
         <xd:p>Maps all datatypes that are explicitly present in the CDAr2 specification. It may not map datatypes you explicitly declare in your instance, e.g. PPD_TS. 
                            Supported dtatypes are: 'AD','BL','BN','CD','CE','CO','CV','ED','EIVL_TS','EN','II','INT','IVL_INT','IVL_MO','IVL_PQ','IVL_REAL','IVL_TS','MO','ON',
                            'PIVL_TS','PN','PQ','REAL','RTO_PQ_PQ','SC','ST','TEL','TS'. In the event this should happen, the XSL gives a message and stops mapping.</xd:p>
         <xd:p>
            <xd:b>NOTE:</xd:b> in datatypes R1 there used to be a qualifier element to coded elements. This no longer exists in datatypes R2. Hence this element is left
                        out of the output. Instead a comment will be add to the output stating what was omitted leading to data loss. Example: 
                            <xd:pre> Could not map qualifier for: name/code="12313" name/codeSystem="1.34" name/displayName="3453" value/code="23123" value/codeSystem="1.2.3" value/displayName="dsf" </xd:pre>
         </xd:p>
         <xd:p>See http://vimeo.com/16813271 for a video by Grahame Grieve on what changed in datatypes R2.</xd:p>
         <xd:p>CDAr2 was not completely moved over to CDAr3 as it currently stands. In the context of where data would/will not be mapped you'll find a comment that 
                            starts with 'Skipping mapping of'. Currently skipped elements include: 'POCD_MT000040.AuthoringDevice.asMaintainedEntity', 'POCD_MT000040.ClinicalDocument.copyTime',
                            'POCD_MT000040.MaintainedEntity.effectiveTime', 'POCD_MT000040.MaintainedEntity.maintainingPerson' and 'POCD_MT000040UV.Patient.id'</xd:p>
      </xd:desc>
   </xd:doc>
   <xsl:output indent="yes"/>
   <xsl:variable name="postalMapping">
      <wrap>
         <map cdar2="additionalLocator" cdar3="ADL"/>
         <map cdar2="unitID" cdar3="UNID"/>
         <map cdar2="unitType" cdar3="UNIT"/>
         <map cdar2="deliveryAddressLine" cdar3="DAL"/>
         <map cdar2="deliveryInstallationType" cdar3="DINST"/>
         <map cdar2="deliveryInstallationArea" cdar3="DINSTA"/>
         <map cdar2="deliveryInstallationQualifier" cdar3="DINSTQ"/>
         <map cdar2="deliveryMode" cdar3="DMOD"/>
         <map cdar2="deliveryModeIdentifier" cdar3="DMODID"/>
         <map cdar2="streetAddressLine" cdar3="SAL"/>
         <map cdar2="houseNumber" cdar3="BNR"/>
         <map cdar2="houseNumberNumeric" cdar3="BNN"/>
         <map cdar2="buildingNumberSuffix" cdar3="BNS"/>
         <map cdar2="streetName" cdar3="STR"/>
         <map cdar2="streetNameBase" cdar3="STB"/>
         <map cdar2="streetNameType" cdar3="STTYP"/>
         <map cdar2="direction" cdar3="DIR"/>
         <map cdar2="careOf" cdar3="CAR"/>
         <map cdar2="censusTract" cdar3="CEN"/>
         <map cdar2="country" cdar3="CNT"/>
         <map cdar2="county" cdar3="CPA"/>
         <map cdar2="city" cdar3="CTY"/>
         <map cdar2="delimiter" cdar3="DEL"/>
         <map cdar2="postBox" cdar3="POB"/>
         <map cdar2="precinct" cdar3="PRE"/>
         <map cdar2="state" cdar3="STA"/>
         <map cdar2="postalCode" cdar3="ZIP"/>
      </wrap>
   </xsl:variable>
   <xsl:template match="/">
      <xsl:apply-templates select="hl7:ClinicalDocument"/>
   </xsl:template>
   <xsl:template match="hl7:ClinicalDocument">
      <xsl:copy>
         <xsl:copy-of select="@*"/>
         <xsl:attribute name="xsi:schemaLocation"
                        select="'urn:hl7-org:v3 cdar3schemas/multicacheschemas/CDA.xsd'"/>
         <xsl:apply-templates select="self::*" mode="POCD_MT000040.ClinicalDocument"/>
      </xsl:copy>
   </xsl:template>
   <!--POCD_MT000040.Act-->
<xsl:template match="*" mode="POCD_MT000040.Act">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.AssignedAuthor-->
<xsl:template match="*" mode="POCD_MT000040.AssignedAuthor">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedPerson">
         <xsl:element name="{if (ancestor::hl7:entry) then ('playingPerson') else ('assignedPerson')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:assignedAuthoringDevice">
         <xsl:element name="{if (ancestor::hl7:entry) then ('playingDevice') else ('assignedDevice')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'DEV'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AuthoringDevice"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:representedOrganization">
         <xsl:element name="{if (ancestor::hl7:entry) then ('scopingOrganization') else ('representedOrganization')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.AssignedCustodian-->
<xsl:template match="*" mode="POCD_MT000040.AssignedCustodian">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:representedCustodianOrganization/hl7:id"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:representedCustodianOrganization">
         <xsl:element name="representedCustodianOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.CustodianOrganization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.AssignedEntity-->
<xsl:template match="*" mode="POCD_MT000040.AssignedEntity">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedPerson">
         <xsl:element name="{if (ancestor::hl7:entry) then ('playingPerson') else ('assignedPerson')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:representedOrganization">
         <xsl:element name="{if (ancestor::hl7:entry) then ('scopingOrganization') else ('representedOrganization')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.AssociatedEntity-->
<xsl:template match="*" mode="POCD_MT000040.AssociatedEntity">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-COLL_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-COLL_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:associatedPerson">
         <xsl:element name="associatedPerson" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:scopingOrganization">
         <xsl:element name="scopingOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Authenticator-->
<xsl:template match="*" mode="POCD_MT000040.Authenticator">
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:signatureCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Author-->
<xsl:template match="*" mode="POCD_MT000040.Author">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:functionCode"/>
      </xsl:call-template>
      <xsl:choose>
         <xsl:when test="ancestor::hl7:entry">
            <xsl:call-template name="dt-TS-to-IVL_TS">
               <xsl:with-param name="in" select="hl7:time"/>
            </xsl:call-template>
         </xsl:when>
         <xsl:otherwise>
            <xsl:call-template name="dt-TS-to-TS">
               <xsl:with-param name="in" select="hl7:time"/>
            </xsl:call-template>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:for-each select="hl7:assignedAuthor">
         <xsl:element name="{if (ancestor::hl7:entry) then ('role') else ('assignedAuthor')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedAuthor"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.AuthoringDevice-->
<xsl:template match="*" mode="POCD_MT000040.AuthoringDevice">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SC-to-SC">
         <xsl:with-param name="in" select="hl7:manufacturerModelName"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SC-to-SC">
         <xsl:with-param name="in" select="hl7:softwareName"/>
      </xsl:call-template>
      <!-- Skipping mapping of 'POCD_MT000040.AuthoringDevice.asMaintainedEntity', because there is no matching 'POCD_MT000040UV.Device.asMaintainedEntity' --><xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Authorization-->
<xsl:template match="*" mode="POCD_MT000040.Authorization">
      <xsl:for-each select="hl7:consent">
         <xsl:element name="consent" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Consent"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Birthplace-->
<xsl:template match="*" mode="POCD_MT000040.Birthplace">
      <xsl:for-each select="hl7:place">
         <xsl:element name="birthplace" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PLC'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Place"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ClinicalDocument-->
<xsl:template match="*" mode="POCD_MT000040.ClinicalDocument">
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ST-to-ST">
         <xsl:with-param name="in" select="hl7:title"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:confidentialityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:setId"/>
      </xsl:call-template>
      <xsl:call-template name="dt-INT-to-ST">
         <xsl:with-param name="in" select="hl7:versionNumber"/>
      </xsl:call-template>
      <!-- Skipping mapping of 'POCD_MT000040.ClinicalDocument.copyTime', because there is no matching 'POCD_MT000040UV.ClinicalDocument.copyTime' --><xsl:for-each select="hl7:recordTarget">
         <xsl:element name="recordTarget" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RecordTarget"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="author" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:dataEnterer">
         <xsl:element name="dataEnterer" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.DataEnterer"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="informant" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:custodian">
         <xsl:element name="custodian" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Custodian"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informationRecipient">
         <xsl:element name="informationRecipient" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCP'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.InformationRecipient"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:legalAuthenticator">
         <xsl:element name="legalAuthenticator" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.LegalAuthenticator"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:authenticator">
         <xsl:element name="authenticator" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Authenticator"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation1" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant1"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:inFulfillmentOf">
         <xsl:element name="inFulfillmentOf" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'FLFS'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="blockedContextParticipationType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'PART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="true()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.InFulfillmentOf"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:documentationOf">
         <xsl:element name="documentationOf" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'DOC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="blockedContextParticipationType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'PART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="true()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.DocumentationOf"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:relatedDocument">
         <xsl:element name="relatedDocument" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="blockedContextParticipationType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'PART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="true()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RelatedDocument"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:authorization">
         <xsl:element name="authorization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUTH'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="blockedContextParticipationType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'PART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="true()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Authorization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:component">
         <xsl:element name="component" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="false()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Component2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:componentOf">
         <xsl:element name="componentOf" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'COMP'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="blockedContextParticipationType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'PART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="true()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Component1"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Component1-->
<xsl:template match="*" mode="POCD_MT000040.Component1">
      <xsl:for-each select="hl7:encompassingEncounter">
         <xsl:element name="encompassingEncounter" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EncompassingEncounter"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Component2-->
<xsl:template match="*" mode="POCD_MT000040.Component2">
      <xsl:for-each select="hl7:nonXMLBody">
         <xsl:element name="nonStructuredBody" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.NonXMLBody"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:structuredBody">
         <xsl:element name="structuredBody" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.StructuredBody"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Component3-->
<xsl:template match="*" mode="POCD_MT000040.Component3">
      <xsl:for-each select="hl7:section">
         <xsl:element name="section" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Section"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Component4-->
<xsl:template match="*" mode="POCD_MT000040.Component4">
      <xsl:call-template name="dt-INT-to-INT">
         <xsl:with-param name="in" select="hl7:sequenceNumber"/>
      </xsl:call-template>
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="hl7:seperatableInd"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:act">
         <xsl:element name="act" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Act"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:encounter">
         <xsl:element name="encounter" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Encounter"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observation">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Observation"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observationMedia">
         <xsl:element name="observationMedia" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ObservationMedia"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:organizer">
         <xsl:element name="{if (@classCode='CLUSTER') then ('composition') else ('observation')}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:if test="@classCode='CLUSTER'">
               <xsl:attribute name="classCode" select="'COMPOSITION'"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organizer"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:procedure">
         <xsl:element name="procedure" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Procedure"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:regionOfInterest">
         <xsl:element name="regionOfInterest" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RegionOfInterest"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:substanceAdministration">
         <xsl:element name="substanceAdministration" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.SubstanceAdministration"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:supply">
         <xsl:element name="supply" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Supply"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Component5-->
<xsl:template match="*" mode="POCD_MT000040.Component5">
      <xsl:for-each select="hl7:section">
         <xsl:element name="section" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Section"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Consent-->
<xsl:template match="*" mode="POCD_MT000040.Consent">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Consumable-->
<xsl:template match="*" mode="POCD_MT000040.Consumable">
      <xsl:for-each select="hl7:manufacturedProduct">
         <xsl:element name="role" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ROL'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ManufacturedProduct"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Criterion-->
<xsl:template match="*" mode="POCD_MT000040.Criterion">
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ANY-to-ANY">
         <xsl:with-param name="in" select="hl7:value"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Custodian-->
<xsl:template match="*" mode="POCD_MT000040.Custodian">
      <xsl:for-each select="hl7:assignedCustodian">
         <xsl:element name="assignedCustodian" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedCustodian"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.CustodianOrganization-->
<xsl:template match="*" mode="POCD_MT000040.CustodianOrganization">
      <xsl:call-template name="dt-ON-to-EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.DataEnterer-->
<xsl:template match="*" mode="POCD_MT000040.DataEnterer">
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Device-->
<xsl:template match="*" mode="POCD_MT000040.Device">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SC-to-SC">
         <xsl:with-param name="in" select="hl7:manufacturerModelName"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SC-to-SC">
         <xsl:with-param name="in" select="hl7:softwareName"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.DocumentationOf-->
<xsl:template match="*" mode="POCD_MT000040.DocumentationOf">
      <xsl:for-each select="hl7:serviceEvent">
         <xsl:element name="serviceEvent" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ServiceEvent"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.EncompassingEncounter-->
<xsl:template match="*" mode="POCD_MT000040.EncompassingEncounter">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:dischargeDispositionCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:responsibleParty">
         <xsl:element name="responsibleParty" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ResponsibleParty"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:encounterParticipant">
         <xsl:element name="encounterParticipant" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EncounterParticipant"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:location">
         <xsl:element name="location" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'LOC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Location"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Encounter-->
<xsl:template match="*" mode="POCD_MT000040.Encounter">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.EncounterParticipant-->
<xsl:template match="*" mode="POCD_MT000040.EncounterParticipant">
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Entity-->
<xsl:template match="*" mode="POCD_MT000040.Entity">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:desc"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Entry-->
<xsl:template match="*" mode="POCD_MT000040.Entry">
      <xsl:for-each select="hl7:act">
         <xsl:element name="act" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Act"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:encounter">
         <xsl:element name="encounter" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Encounter"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observation">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Observation"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observationMedia">
         <xsl:element name="observationMedia" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ObservationMedia"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:organizer">
         <xsl:element name="{if (@classCode='CLUSTER') then ('composition') else ('observation')}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:if test="@classCode='CLUSTER'">
               <xsl:attribute name="classCode" select="'COMPOSITION'"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organizer"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:procedure">
         <xsl:element name="procedure" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Procedure"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:regionOfInterest">
         <xsl:element name="regionOfInterest" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RegionOfInterest"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:substanceAdministration">
         <xsl:element name="substanceAdministration" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.SubstanceAdministration"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:supply">
         <xsl:element name="supply" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Supply"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.EntryRelationship-->
<xsl:template match="*" mode="POCD_MT000040.EntryRelationship">
      <xsl:call-template name="dt-INT-to-INT">
         <xsl:with-param name="in" select="hl7:sequenceNumber"/>
      </xsl:call-template>
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="hl7:seperatableInd"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:act">
         <xsl:element name="act" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Act"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:encounter">
         <xsl:element name="encounter" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Encounter"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observation">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Observation"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:observationMedia">
         <xsl:element name="observationMedia" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ObservationMedia"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:organizer">
         <xsl:element name="{if (@classCode='CLUSTER') then ('composition') else ('observation')}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:if test="@classCode='CLUSTER'">
               <xsl:attribute name="classCode" select="'COMPOSITION'"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organizer"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:procedure">
         <xsl:element name="procedure" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Procedure"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:regionOfInterest">
         <xsl:element name="regionOfInterest" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RegionOfInterest"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:substanceAdministration">
         <xsl:element name="substanceAdministration" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.SubstanceAdministration"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:supply">
         <xsl:element name="supply" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Supply"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ExternalAct-->
<xsl:template match="*" mode="POCD_MT000040.ExternalAct">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ExternalDocument-->
<xsl:template match="*" mode="POCD_MT000040.ExternalDocument">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:setId"/>
      </xsl:call-template>
      <xsl:call-template name="dt-INT-to-ST">
         <xsl:with-param name="in" select="hl7:versionNumber"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ExternalObservation-->
<xsl:template match="*" mode="POCD_MT000040.ExternalObservation">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ExternalProcedure-->
<xsl:template match="*" mode="POCD_MT000040.ExternalProcedure">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Guardian-->
<xsl:template match="*" mode="POCD_MT000040.Guardian">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:guardianPerson">
         <xsl:element name="guardianPerson" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:guardianOrganization">
         <xsl:element name="guardianOrganization" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.HealthCareFacility-->
<xsl:template match="*" mode="POCD_MT000040.HealthCareFacility">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:location">
         <xsl:element name="playingPlace" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PLC'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Place"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:serviceProviderOrganization">
         <xsl:element name="scopingOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Informant12-->
<xsl:template match="*" mode="POCD_MT000040.Informant12">
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="{if (ancestor::hl7:entry) then ('role') else ('assignedEntity')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:relatedEntity">
         <xsl:element name="{if (ancestor::hl7:entry) then ('role') else ('relatedEntity')}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RelatedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.InformationRecipient-->
<xsl:template match="*" mode="POCD_MT000040.InformationRecipient">
      <xsl:for-each select="hl7:intendedRecipient">
         <xsl:element name="intendedRecipient" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.IntendedRecipient"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.InFulfillmentOf-->
<xsl:template match="*" mode="POCD_MT000040.InFulfillmentOf">
      <xsl:for-each select="hl7:order">
         <xsl:element name="order" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ACT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Order"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.IntendedRecipient-->
<xsl:template match="*" mode="POCD_MT000040.IntendedRecipient">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:informationRecipient">
         <xsl:element name="informationRecipient" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:receivedOrganization">
         <xsl:element name="receivedOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.LabeledDrug-->
<xsl:template match="*" mode="POCD_MT000040.LabeledDrug">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-EN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.LanguageCommunication-->
<xsl:template match="*" mode="POCD_MT000040.LanguageCommunication">
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:modeCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:proficiencyLevelCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="hl7:preferenceInd"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.LegalAuthenticator-->
<xsl:template match="*" mode="POCD_MT000040.LegalAuthenticator">
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:signatureCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Location-->
<xsl:template match="*" mode="POCD_MT000040.Location">
      <xsl:for-each select="hl7:healthCareFacility">
         <xsl:element name="healthCareFacility" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'SDLOC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.HealthCareFacility"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.MaintainedEntity-->
<xsl:template match="*" mode="POCD_MT000040.MaintainedEntity"><!-- Skipping mapping of 'POCD_MT000040.MaintainedEntity.effectiveTime', because there is no matching 'POCD_MT000040UV.MaintainedEntity.effectiveTime' --><!-- Skipping mapping of 'POCD_MT000040.MaintainedEntity.maintainingPerson', because there is no matching 'POCD_MT000040UV.MaintainedEntity.maintainingPerson' --><xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ManufacturedProduct-->
<xsl:template match="*" mode="POCD_MT000040.ManufacturedProduct">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:manufacturedLabeledDrug">
         <xsl:element name="playingManufacturedMaterial" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'MMAT'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.LabeledDrug"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:manufacturedMaterial">
         <xsl:element name="playingManufacturedMaterial" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'MMAT'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Material"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:manufacturerOrganization">
         <xsl:element name="scopingOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Material-->
<xsl:template match="*" mode="POCD_MT000040.Material">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-EN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ST-to-ST">
         <xsl:with-param name="in" select="hl7:lotNumberText"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.NonXMLBody-->
<xsl:template match="*" mode="POCD_MT000040.NonXMLBody">
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:confidentialityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Observation-->
<xsl:template match="*" mode="POCD_MT000040.Observation">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ST-to-ST">
         <xsl:with-param name="in" select="hl7:derivationExpr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_INT-to-IVL_INT">
         <xsl:with-param name="in" select="hl7:repeatNumber"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ANY-to-ANY">
         <xsl:with-param name="in" select="hl7:value"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:interpretationCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:methodCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:targetSiteCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:referenceRange">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'REFV'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ReferenceRange"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ObservationMedia-->
<xsl:template match="*" mode="POCD_MT000040.ObservationMedia">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:value"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ObservationRange-->
<xsl:template match="*" mode="POCD_MT000040.ObservationRange">
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ANY-to-ANY">
         <xsl:with-param name="in" select="hl7:value"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:interpretationCode"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Order-->
<xsl:template match="*" mode="POCD_MT000040.Order">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Organization-->
<xsl:template match="*" mode="POCD_MT000040.Organization">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ON-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:standardIndustryClassCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:asOrganizationPartOf">
         <xsl:element name="asOrganizationPartOf" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PART'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.OrganizationPartOf"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.OrganizationPartOf-->
<xsl:template match="*" mode="POCD_MT000040.OrganizationPartOf">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:wholeOrganization">
         <xsl:element name="wholeOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Organizer-->
<xsl:template match="*" mode="POCD_MT000040.Organizer">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-QSET_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:component">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'COMP'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Component4"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ParentDocument-->
<xsl:template match="*" mode="POCD_MT000040.ParentDocument">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:setId"/>
      </xsl:call-template>
      <xsl:call-template name="dt-INT-to-ST">
         <xsl:with-param name="in" select="hl7:versionNumber"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Participant1-->
<xsl:template match="*" mode="POCD_MT000040.Participant1">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:functionCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:associatedEntity">
         <xsl:element name="associatedEntity" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssociatedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Participant2-->
<xsl:template match="*" mode="POCD_MT000040.Participant2">
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:awarenessCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:participantRole">
         <xsl:element name="role" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ROL'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ParticipantRole"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ParticipantRole-->
<xsl:template match="*" mode="POCD_MT000040.ParticipantRole">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:playingDevice">
         <xsl:element name="playingDevice" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'DEV'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Device"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:playingEntity">
         <xsl:element name="playingEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ENT'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.PlayingEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:scopingEntity">
         <xsl:element name="scopingEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ENT'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Entity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Patient-->
<xsl:template match="*" mode="POCD_MT000040.Patient"><!-- Skipping mapping of 'POCD_MT000040.Patient.id', because there is no matching 'POCD_MT000040UV.Patient.id' --><xsl:call-template name="dt-PN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:administrativeGenderCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:birthTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:maritalStatusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:religiousAffiliationCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:raceCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:ethnicGroupCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:guardian">
         <xsl:element name="guardian" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Guardian"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:birthplace">
         <xsl:element name="birthplace" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Birthplace"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:languageCommunication">
         <xsl:element name="languageCommunication" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.LanguageCommunication"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.PatientRole-->
<xsl:template match="*" mode="POCD_MT000040.PatientRole">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:patient">
         <xsl:element name="patient" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Patient"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:providerOrganization">
         <xsl:element name="providerOrganization" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ORG'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Organization"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Performer1-->
<xsl:template match="*" mode="POCD_MT000040.Performer1">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:functionCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Performer2-->
<xsl:template match="*" mode="POCD_MT000040.Performer2">
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:time"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:modeCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="role" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Person-->
<xsl:template match="*" mode="POCD_MT000040.Person">
      <xsl:call-template name="dt-PN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Place-->
<xsl:template match="*" mode="POCD_MT000040.Place">
      <xsl:call-template name="dt-EN-to-EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.PlayingEntity-->
<xsl:template match="*" mode="POCD_MT000040.PlayingEntity">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-PQ-to-PQ">
         <xsl:with-param name="in" select="hl7:quantity"/>
      </xsl:call-template>
      <xsl:call-template name="dt-PN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:desc"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Precondition-->
<xsl:template match="*" mode="POCD_MT000040.Precondition">
      <xsl:for-each select="hl7:criterion">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'OBS'"/>
            <xsl:attribute name="moodCode" select="'EVN.CRT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Criterion"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Procedure-->
<xsl:template match="*" mode="POCD_MT000040.Procedure">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:methodCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:approachSiteCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:targetSiteCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Product-->
<xsl:template match="*" mode="POCD_MT000040.Product">
      <xsl:for-each select="hl7:manufacturedProduct">
         <xsl:element name="role" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ManufacturedProduct"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RecordTarget-->
<xsl:template match="*" mode="POCD_MT000040.RecordTarget">
      <xsl:for-each select="hl7:patientRole">
         <xsl:element name="patientRole" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.PatientRole"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Reference-->
<xsl:template match="*" mode="POCD_MT000040.Reference">
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="hl7:seperatableInd"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:externalAct">
         <xsl:element name="act" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ACT'"/>
            <xsl:attribute name="moodCode" select="'EVN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ExternalAct"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:externalObservation">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'OBS'"/>
            <xsl:attribute name="moodCode" select="'EVN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ExternalObservation"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:externalProcedure">
         <xsl:element name="procedure" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PROC'"/>
            <xsl:attribute name="moodCode" select="'EVN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ExternalProcedure"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:externalDocument">
         <xsl:element name="document" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'DOC'"/>
            <xsl:attribute name="moodCode" select="'EVN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ExternalDocument"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ReferenceRange-->
<xsl:template match="*" mode="POCD_MT000040.ReferenceRange">
      <xsl:for-each select="hl7:observationRange">
         <xsl:element name="observation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'OBS'"/>
            <xsl:attribute name="moodCode" select="'EVN.CRT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ObservationRange"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RegionOfInterest.value-->
<xsl:template match="*" mode="POCD_MT000040.RegionOfInterest.value">
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RegionOfInterest-->
<xsl:template match="*" mode="POCD_MT000040.RegionOfInterest">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:value">
         <xsl:element name="value" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RegionOfInterest.value"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RelatedDocument-->
<xsl:template match="*" mode="POCD_MT000040.RelatedDocument">
      <xsl:for-each select="hl7:parentDocument">
         <xsl:element name="parentDocument" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'DOCCLIN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.ParentDocument"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RelatedEntity-->
<xsl:template match="*" mode="POCD_MT000040.RelatedEntity">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:relatedPerson">
         <xsl:element name="{if (ancestor::hl7:entry) then ('playingPerson') else ('relatedPerson')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Person"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.RelatedSubject-->
<xsl:template match="*" mode="POCD_MT000040.RelatedSubject">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="hl7:addr"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="hl7:telecom"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="{if (ancestor::hl7:entry) then ('playingPerson') else ('subject')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PSN'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.SubjectPerson"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ResponsibleParty-->
<xsl:template match="*" mode="POCD_MT000040.ResponsibleParty">
      <xsl:for-each select="hl7:assignedEntity">
         <xsl:element name="assignedEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ASSIGNED'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.AssignedEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Section-->
<xsl:template match="*" mode="POCD_MT000040.Section">
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ST-to-ST">
         <xsl:with-param name="in" select="hl7:title"/>
      </xsl:call-template>
      <xsl:call-template name="dt-StrucDoc.Text-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:confidentialityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="subject" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="author" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="informant" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entry">
         <xsl:element name="entry" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode"
                           select="if (../hl7:*[@typeCode='DRIV']) then ('DRIV') else ('COMP')"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="false()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Entry"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:component">
         <xsl:element name="component" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="false()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Component5"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.ServiceEvent-->
<xsl:template match="*" mode="POCD_MT000040.ServiceEvent">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="performer" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer1"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Specimen-->
<xsl:template match="*" mode="POCD_MT000040.Specimen">
      <xsl:for-each select="hl7:specimenRole">
         <xsl:element name="role" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.SpecimenRole"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.SpecimenRole-->
<xsl:template match="*" mode="POCD_MT000040.SpecimenRole">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:specimenPlayingEntity">
         <xsl:element name="playingEntity" namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'ENT'"/>
            <xsl:attribute name="determinerCode" select="'INSTANCE'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.PlayingEntity"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.StructuredBody-->
<xsl:template match="*" mode="POCD_MT000040.StructuredBody">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:confidentialityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CD">
         <xsl:with-param name="in" select="hl7:languageCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:component">
         <xsl:element name="component" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:element name="blockedContextActRelationshipType" namespace="urn:hl7-org:v3">
               <xsl:attribute name="code" select="'ART'"/>
            </xsl:element>
            <xsl:element name="actAttributeContextBlockedInd" namespace="urn:hl7-org:v3">
               <xsl:attribute name="value" select="false()"/>
            </xsl:element>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Component3"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Subject-->
<xsl:template match="*" mode="POCD_MT000040.Subject">
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:awarenessCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:relatedSubject">
         <xsl:element name="{if (ancestor::hl7:entry) then ('role') else ('relatedSubject')}"
                      namespace="urn:hl7-org:v3">
            <xsl:attribute name="classCode" select="'PRS'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.RelatedSubject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.SubjectPerson-->
<xsl:template match="*" mode="POCD_MT000040.SubjectPerson">
      <xsl:call-template name="dt-PN-to-DSET_EN">
         <xsl:with-param name="in" select="hl7:name"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:administrativeGenderCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-TS-to-TS">
         <xsl:with-param name="in" select="hl7:birthTime"/>
      </xsl:call-template>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.SubstanceAdministration-->
<xsl:template match="*" mode="POCD_MT000040.SubstanceAdministration">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SXCM_TS-to-QSET_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_INT-to-IVL_INT">
         <xsl:with-param name="in" select="hl7:repeatNumber"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:routeCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:approachSiteCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_PQ-to-PQ">
         <xsl:with-param name="in" select="hl7:doseQuantity"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_PQ-to-PQ">
         <xsl:with-param name="in" select="hl7:rateQuantity"/>
      </xsl:call-template>
      <xsl:call-template name="dt-RTO_PQ_PQ-to-DSET_RTO">
         <xsl:with-param name="in" select="hl7:maxDoseQuantity"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-CD">
         <xsl:with-param name="in" select="hl7:administrationUnitCode"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:consumable">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'CSM'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Consumable"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!--POCD_MT000040.Supply-->
<xsl:template match="*" mode="POCD_MT000040.Supply">
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:id"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="hl7:code"/>
      </xsl:call-template>
      <xsl:call-template name="dt-ED-to-ED">
         <xsl:with-param name="in" select="hl7:text"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CS-to-CS">
         <xsl:with-param name="in" select="hl7:statusCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-SXCM_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:effectiveTime"/>
      </xsl:call-template>
      <xsl:call-template name="dt-CE-to-DSET_CD">
         <xsl:with-param name="in" select="hl7:priorityCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_INT-to-IVL_INT">
         <xsl:with-param name="in" select="hl7:repeatNumber"/>
      </xsl:call-template>
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="hl7:independentInd"/>
      </xsl:call-template>
      <xsl:call-template name="dt-PQ-to-PQ">
         <xsl:with-param name="in" select="hl7:quantity"/>
      </xsl:call-template>
      <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
         <xsl:with-param name="in" select="hl7:expectedUseTime"/>
      </xsl:call-template>
      <xsl:for-each select="hl7:subject">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SBJ'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Subject"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:specimen">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'SPC'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Specimen"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:product">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRD'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Product"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:performer">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Performer2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:author">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'AUT'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Author"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:informant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'INF'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Informant12"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:participant">
         <xsl:element name="participation" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Participant2"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:entryRelationship">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.EntryRelationship"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:reference">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Reference"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:for-each select="hl7:precondition">
         <xsl:element name="outboundRelationship" namespace="urn:hl7-org:v3">
            <xsl:attribute name="typeCode" select="'PRCN'"/>
            <xsl:copy-of select="@nullFlavor|@typeCode|@classCode|@moodCode|@determinerCode|@inversionInd"/>
            <xsl:if test="self::node()[@negationInd]">
               <xsl:attribute name="actionNegationInd" select="@negationInd"/>
            </xsl:if>
            <xsl:call-template name="infrastructureRootElements"/>
            <xsl:apply-templates select="self::*" mode="POCD_MT000040.Precondition"/>
         </xsl:element>
      </xsl:for-each>
      <xsl:apply-templates select="*[not(namespace-uri()='urn:hl7-org:v3')]"/>
   </xsl:template>
   <!-- infrastructureRootElements --><xsl:template name="infrastructureRootElements">
      <xsl:call-template name="dt-CS-to-DSET_CS">
         <xsl:with-param name="in" select="hl7:realmCode"/>
      </xsl:call-template>
      <xsl:call-template name="dt-II-to-II">
         <xsl:with-param name="in" select="hl7:typeId"/>
      </xsl:call-template>
      <xsl:call-template name="dt-II-to-DSET_II">
         <xsl:with-param name="in" select="hl7:templateId"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-AD-to-AD -->
<xsl:template name="dt-AD-to-AD">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@use|$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:if test="$in/hl7:useablePeriod/hl7:low[@value]">
               <xsl:attribute name="validTimeLow" select="$in/hl7:useablePeriod/hl7:low/@value"/>
            </xsl:if>
            <xsl:if test="$in/hl7:useablePeriod/hl7:high[@value]">
               <xsl:attribute name="validTimeHigh" select="$in/hl7:useablePeriod/hl7:high/@value"/>
            </xsl:if>
            <xsl:for-each select="$in/text()[string-length(normalize-space(.))&gt;0]|$in/hl7:*[not(self::hl7:useablePeriod)]">
               <xsl:variable name="partType">
                  <xsl:variable name="partName" select="local-name()"/>
                  <xsl:value-of select="$postalMapping//map[@cdar2=$partName]/@cdar3"/>
               </xsl:variable>
               <xsl:element name="part" namespace="urn:hl7-org:v3">
                  <xsl:for-each select="@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor">
                     <xsl:attribute name="{name()}" select="."/>
                  </xsl:for-each>
                  <xsl:if test="string-length($partType)&gt;0">
                     <xsl:attribute name="type" select="$partType"/>
                  </xsl:if>
                  <xsl:attribute name="value" select="."/>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-AD-to-COLL_AD -->
<xsl:template name="dt-AD-to-COLL_AD">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-AD-to-DSET_AD">
         <xsl:with-param name="in" select="$in"/>
         <xsl:with-param name="dt" select="'DSET_AD'"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-AD-to-DSET_AD -->
<xsl:template name="dt-AD-to-DSET_AD">
      <xsl:param name="in"/>
      <xsl:param name="dt"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:if test="$in[1]/@xsi:type or string-length($dt)&gt;0">
               <xsl:attribute name="xsi:type" select="'DSET_AD'"/>
            </xsl:if>
            <xsl:for-each select="$in">
               <xsl:element name="item" namespace="urn:hl7-org:v3">
                  <xsl:for-each select="@use|@nullFlavor">
                     <xsl:attribute name="{name()}" select="."/>
                  </xsl:for-each>
                  <xsl:if test="hl7:useablePeriod/hl7:low[@value]">
                     <xsl:attribute name="validTimeLow" select="hl7:useablePeriod/hl7:low/@value"/>
                  </xsl:if>
                  <xsl:if test="hl7:useablePeriod/hl7:high[@value]">
                     <xsl:attribute name="validTimeHigh" select="hl7:useablePeriod/hl7:high/@value"/>
                  </xsl:if>
                  <xsl:for-each select="text()[string-length(normalize-space(.))&gt;0]|hl7:*[not(self::hl7:useablePeriod)]">
                     <xsl:variable name="partType">
                        <xsl:variable name="partName" select="local-name()"/>
                        <xsl:value-of select="$postalMapping//map[@cdar2=$partName]/@cdar3"/>
                     </xsl:variable>
                     <xsl:element name="part" namespace="urn:hl7-org:v3">
                        <xsl:for-each select="@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor">
                           <xsl:attribute name="{name()}" select="."/>
                        </xsl:for-each>
                        <xsl:if test="string-length($partType)&gt;0">
                           <xsl:attribute name="type" select="$partType"/>
                        </xsl:if>
                        <xsl:attribute name="value" select="."/>
                     </xsl:element>
                  </xsl:for-each>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-ANY-to-ANY -->
<xsl:template name="dt-ANY-to-ANY">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:choose>
            <xsl:when test="$in/@xsi:type='AD'">
               <xsl:call-template name="dt-AD-to-AD">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='BL'">
               <xsl:call-template name="dt-BL-to-BL">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='BN'">
               <xsl:call-template name="dt-BN-to-BN">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='CD'">
               <xsl:call-template name="dt-CD-to-CD">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='CE'">
               <xsl:call-template name="dt-CE-to-CE">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='CO'">
               <xsl:call-template name="dt-CO-to-CO">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='CV'">
               <xsl:call-template name="dt-CV-to-CV">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='ED'">
               <xsl:call-template name="dt-ED-to-ED">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='EIVL_TS'">
               <xsl:call-template name="dt-EIVL_TS-to-EIVL_TS">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='EN'">
               <xsl:call-template name="dt-EN-to-EN">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='II'">
               <xsl:call-template name="dt-II-to-II">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='INT'">
               <xsl:call-template name="dt-INT-to-INT">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='IVL_INT'">
               <xsl:call-template name="dt-IVL_INT-to-IVL_INT">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='IVL_MO'">
               <xsl:call-template name="dt-IVL_MO-to-IVL_MO">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='IVL_PQ'">
               <xsl:call-template name="dt-IVL_PQ-to-IVL_PQ">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='IVL_REAL'">
               <xsl:call-template name="dt-IVL_REAL-to-IVL_REAL">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='IVL_TS'">
               <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='MO'">
               <xsl:call-template name="dt-MO-to-MO">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='ON'">
               <xsl:call-template name="dt-ON-to-ON">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='PIVL_TS'">
               <xsl:call-template name="dt-PIVL_TS-to-PIVL_TS">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='PN'">
               <xsl:call-template name="dt-PN-to-PN">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='PQ'">
               <xsl:call-template name="dt-PQ-to-PQ">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='REAL'">
               <xsl:call-template name="dt-REAL-to-REAL">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='RTO_PQ_PQ'">
               <xsl:call-template name="dt-RTO_PQ_PQ-to-RTO_PQ_PQ">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='SC'">
               <xsl:call-template name="dt-SC-to-SC">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='ST'">
               <xsl:call-template name="dt-ST-to-ST">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='TEL'">
               <xsl:call-template name="dt-TEL-to-TEL">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='TS'">
               <xsl:call-template name="dt-TS-to-TS">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
               <xsl:message terminate="yes"> ERROR Found unsupported datatype '<xsl:value-of select="$in/@xsi:type"/>' in <xsl:value-of select="$in[1]/name()"/>
               </xsl:message>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:if>
   </xsl:template>
   <!-- dt-BL-to-BL -->
<xsl:template name="dt-BL-to-BL">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@value|$in/@nullFlavor|$in/@xsi:type"/>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-BN-to-BN -->
<xsl:template name="dt-BN-to-BN">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-BL-to-BL">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-CD-to-CD -->
<xsl:template name="dt-CD-to-CD">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:if test="$in[@xsi:type]">
               <xsl:choose>
                  <xsl:when test="$in/@xsi:type='CO' or $in/@xsi:type='CS'">
                     <xsl:attribute name="xsi:type" select="$in/@xsi:type"/>
                  </xsl:when>
                  <xsl:otherwise>
                     <xsl:attribute name="xsi:type" select="'CD'"/>
                  </xsl:otherwise>
               </xsl:choose>
            </xsl:if>
            <xsl:copy-of select="$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion|$in/@nullFlavor"/>
            <xsl:if test="$in[@displayName]">
               <xsl:element name="displayName" namespace="urn:hl7-org:v3">
                  <xsl:attribute name="value" select="$in/@displayName"/>
               </xsl:element>
            </xsl:if>
            <xsl:call-template name="dt-ED-to-ED">
               <xsl:with-param name="in" select="$in/hl7:originalText"/>
            </xsl:call-template>
            <xsl:call-template name="dt-CR-to-DSET_CR">
               <xsl:with-param name="in" select="$in/hl7:qualifier"/>
            </xsl:call-template>
            <xsl:call-template name="dt-CD-to-CD">
               <xsl:with-param name="in" select="$in/hl7:translation"/>
            </xsl:call-template>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-CD-to-DSET_CD -->
<xsl:template name="dt-CD-to-DSET_CD">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:if test="$in[@xsi:type]">
               <xsl:attribute name="xsi:type" select="'DSET_CD'"/>
            </xsl:if>
            <xsl:for-each select="$in">
               <item xmlns="urn:hl7-org:v3">
                  <xsl:for-each select="@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor">
                     <xsl:attribute name="{name()}" select="."/>
                  </xsl:for-each>
                  <xsl:if test="self::node()[@displayName]">
                     <displayName>
                        <xsl:attribute name="value" select="@displayName"/>
                     </displayName>
                  </xsl:if>
                  <xsl:call-template name="dt-ED-to-ED">
                     <xsl:with-param name="in" select="hl7:originalText"/>
                  </xsl:call-template>
                  <xsl:call-template name="dt-CR-to-DSET_CR">
                     <xsl:with-param name="in" select="hl7:qualifier"/>
                  </xsl:call-template>
                  <xsl:call-template name="dt-CD-to-CD">
                     <xsl:with-param name="in" select="hl7:translation"/>
                  </xsl:call-template>
               </item>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-CE-to-CE -->
<xsl:template name="dt-CE-to-CE">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-CE-to-CD -->
<xsl:template name="dt-CE-to-CD">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-CE-to-DSET_CD -->
<xsl:template name="dt-CE-to-DSET_CD">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-CD-to-DSET_CD">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-CO-to-CO -->
<xsl:template name="dt-CO-to-CO">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:if test="$in[@code]">
               <xsl:element name="code" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion|$in/@nullFlavor"/>
                  <xsl:if test="$in[@displayName]">
                     <xsl:element name="displayName" namespace="urn:hl7-org:v3">
                        <xsl:attribute name="value" select="$in/@displayName"/>
                     </xsl:element>
                  </xsl:if>
                  <xsl:call-template name="dt-ED-to-ED">
                     <xsl:with-param name="in" select="$in/hl7:originalText"/>
                  </xsl:call-template>
               </xsl:element>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-CR-to-DSET_CR -->
<xsl:template name="dt-CR-to-DSET_CR">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:comment> Could not map qualifier for: <xsl:for-each select="$in/hl7:name/@code|$in/hl7:name/@codeSystem|$in/hl7:name/@displayName|$in/hl7:value/@code|$in/hl7:value/@codeSystem|$in/hl7:value/@displayName">
               <xsl:value-of select="concat(name(..),'/',name(),'=&#34;',.,'&#34; ')"/>
            </xsl:for-each>
         </xsl:comment>
      </xsl:if>
   </xsl:template>
   <!-- dt-CS-to-CS -->
<xsl:template name="dt-CS-to-CS">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-CS-to-CD -->
<xsl:template name="dt-CS-to-CD">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-CS-to-DSET_CS -->
<xsl:template name="dt-CS-to-DSET_CS">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:for-each select="$in">
               <item xmlns="urn:hl7-org:v3">
                  <xsl:copy-of select="@code|@nullFlavor"/>
               </item>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-CV-to-CV -->
<xsl:template name="dt-CV-to-CV">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-CD-to-CD">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-ED-to-ED -->
<xsl:template name="dt-ED-to-ED">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@mediaType|$in/@language|$in/@compression|$in/@nullFlavor|$in/@xsi:type"/>
            <!-- SHA-1 is now SHA1 and SHA-256 is now SHA256 --><xsl:if test="$in/@integrityCheckAlgorithm">
               <xsl:attribute name="integrityCheckAlgorithm"
                              select="replace($in/@integrityCheckAlgorithm,'-','')"/>
            </xsl:if>
            <xsl:if test="$in/text()[string-length(normalize-space(.))&gt;0]">
               <xsl:choose>
                  <xsl:when test="$in/@representation='B64'">
                     <xsl:element name="data" namespace="urn:hl7-org:v3">
                        <xsl:copy-of select="$in/text()[string-length(normalize-space(.))&gt;0]"/>
                     </xsl:element>
                  </xsl:when>
                  <xsl:otherwise>
                     <xsl:element name="xml" namespace="urn:hl7-org:v3">
                        <xsl:copy-of select="$in/text()[string-length(normalize-space(.))&gt;0]"/>
                     </xsl:element>
                  </xsl:otherwise>
               </xsl:choose>
            </xsl:if>
            <xsl:copy-of select="$in/hl7:reference"/>
            <xsl:copy-of select="$in/hl7:thumbnail"/>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-EIVL_TS-to-EIVL_TS -->
<xsl:template name="dt-EIVL_TS-to-EIVL_TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:if test="$in/hl7:event/@code">
               <xsl:attribute name="event" select="$in/hl7:event/@code"/>
            </xsl:if>
            <xsl:if test="$in/hl7:offset">
               <xsl:call-template name="dt-IVL_PQ-to-IVL_PQ">
                  <xsl:with-param name="in" select="$in/hl7:offset"/>
               </xsl:call-template>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-EN-to-EN -->
<xsl:template name="dt-EN-to-EN">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <!-- @use code 'L' needs to be 'C'. Only one other code with an 'L' which is 'SYL'. Replace SYL, replace L, restore SYL --><xsl:if test="$in/@use">
               <xsl:attribute name="use"
                              select="replace(replace(replace($in/@use,'SYL','SYK'),'L','C'),'SYK','SYL')"/>
            </xsl:if>
            <xsl:if test="$in/hl7:validTime/hl7:low[@value]">
               <xsl:attribute name="validTimeLow" select="$in/hl7:validTime/hl7:low/@value"/>
            </xsl:if>
            <xsl:if test="$in/hl7:validTime/hl7:high[@value]">
               <xsl:attribute name="validTimeHigh" select="$in/hl7:validTime/hl7:high/@value"/>
            </xsl:if>
            <xsl:for-each select="$in/text()[string-length(normalize-space(.))&gt;0]|$in/hl7:*[not(self::hl7:validTime)]">
               <xsl:variable name="partType">
                  <xsl:choose>
                     <xsl:when test="self::hl7:given or self::hl7:prefix or self::hl7:suffix">
                        <xsl:text>GIV</xsl:text>
                     </xsl:when>
                     <xsl:when test="self::hl7:family">
                        <xsl:text>FAM</xsl:text>
                     </xsl:when>
                     <xsl:when test="self::hl7:delimiter">
                        <xsl:text>DEL</xsl:text>
                     </xsl:when>
                     <xsl:when test="self::hl7:title">
                        <xsl:text>TITLE</xsl:text>
                     </xsl:when>
                  </xsl:choose>
               </xsl:variable>
               <xsl:variable name="partQualifier">
                  <xsl:variable name="partQualifierExtra">
                     <xsl:choose>
                        <xsl:when test="self::hl7:prefix">
                           <xsl:text> PFX</xsl:text>
                        </xsl:when>
                        <xsl:when test="self::hl7:suffix">
                           <xsl:text> SFX</xsl:text>
                        </xsl:when>
                     </xsl:choose>
                  </xsl:variable>
                  <xsl:value-of select="normalize-space(concat(@qualifier,$partQualifierExtra))"/>
               </xsl:variable>
               <xsl:element name="part" namespace="urn:hl7-org:v3">
                  <xsl:for-each select="@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor">
                     <xsl:attribute name="{name()}" select="."/>
                  </xsl:for-each>
                  <xsl:if test="string-length($partType)&gt;0">
                     <xsl:attribute name="type" select="$partType"/>
                  </xsl:if>
                  <xsl:attribute name="value" select="."/>
                  <xsl:if test="string-length($partQualifier)&gt;0">
                     <xsl:attribute name="qualifier" select="$partQualifier"/>
                  </xsl:if>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-EN-to-DSET_EN -->
<xsl:template name="dt-EN-to-DSET_EN">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:for-each select="$in">
               <xsl:element name="item" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="@nullFlavor|@xsi:type"/>
                  <!-- @use code 'L' needs to be 'C'. Only one other code with an 'L' which is 'SYL'. Replace SYL, replace L, restore SYL --><xsl:if test="@use">
                     <xsl:attribute name="use"
                                    select="replace(replace(replace(@use,'SYL','SYK'),'L','C'),'SYK','SYL')"/>
                  </xsl:if>
                  <xsl:if test="hl7:validTime/hl7:low[@value]">
                     <xsl:attribute name="validTimeLow" select="hl7:validTime/hl7:low/@value"/>
                  </xsl:if>
                  <xsl:if test="hl7:validTime/hl7:high[@value]">
                     <xsl:attribute name="validTimeHigh" select="hl7:validTime/hl7:high/@value"/>
                  </xsl:if>
                  <xsl:for-each select="text()[string-length(normalize-space(.))&gt;0]|hl7:*[not(self::hl7:validTime)]">
                     <xsl:variable name="partType">
                        <xsl:choose>
                           <xsl:when test="self::hl7:given or self::hl7:prefix or self::hl7:suffix">
                              <xsl:text>GIV</xsl:text>
                           </xsl:when>
                           <xsl:when test="self::hl7:family">
                              <xsl:text>FAM</xsl:text>
                           </xsl:when>
                           <xsl:when test="self::hl7:delimiter">
                              <xsl:text>DEL</xsl:text>
                           </xsl:when>
                           <xsl:when test="self::hl7:title">
                              <xsl:text>TITLE</xsl:text>
                           </xsl:when>
                        </xsl:choose>
                     </xsl:variable>
                     <xsl:variable name="partQualifier">
                        <xsl:variable name="partQualifierExtra">
                           <xsl:choose>
                              <xsl:when test="self::hl7:prefix">
                                 <xsl:text> PFX</xsl:text>
                              </xsl:when>
                              <xsl:when test="self::hl7:suffix">
                                 <xsl:text> SFX</xsl:text>
                              </xsl:when>
                           </xsl:choose>
                        </xsl:variable>
                        <xsl:value-of select="normalize-space(concat(@qualifier,$partQualifierExtra))"/>
                     </xsl:variable>
                     <xsl:element name="part" namespace="urn:hl7-org:v3">
                        <xsl:for-each select="@code|@codeSystem|@codeSystemName|@codeSystemVersion|@nullFlavor">
                           <xsl:attribute name="{name()}" select="."/>
                        </xsl:for-each>
                        <xsl:if test="string-length($partType)&gt;0">
                           <xsl:attribute name="type" select="$partType"/>
                        </xsl:if>
                        <xsl:attribute name="value" select="."/>
                        <xsl:if test="string-length($partQualifier)&gt;0">
                           <xsl:attribute name="qualifier" select="$partQualifier"/>
                        </xsl:if>
                     </xsl:element>
                  </xsl:for-each>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-II-to-II -->
<xsl:template name="dt-II-to-II">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@root|$in/@extension|$in/@nullFlavor|$in/@xsi:type"/>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-II-to-DSET_II -->
<xsl:template name="dt-II-to-DSET_II">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:for-each select="$in">
               <item xmlns="urn:hl7-org:v3">
                  <xsl:copy-of select="@root|@extension|@nullFlavor|@xsi:type"/>
               </item>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-INT-to-INT -->
<xsl:template name="dt-INT-to-INT">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-INT-to-ST -->
<xsl:template name="dt-INT-to-ST">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:attribute name="value" select="$in/@value"/>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-IVL-to-IVL -->
<xsl:template name="dt-IVL-to-IVL">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:param name="dt"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{if (string-length($nm)&gt;0) then ($nm) else (name($in))}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:if test="string-length($dt)&gt;0">
               <xsl:attribute name="xsi:type" select="$dt"/>
            </xsl:if>
            <xsl:if test="$in/hl7:low/@inclusive">
               <xsl:attribute name="lowClosed" select="$in/hl7:low/@inclusive"/>
            </xsl:if>
            <xsl:if test="$in/hl7:high/@inclusive">
               <xsl:attribute name="highClosed" select="$in/hl7:high/@inclusive"/>
            </xsl:if>
            <xsl:for-each select="$in/hl7:low|$in/hl7:high|$in/width">
               <xsl:element name="{name()}" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="@value|@unit|@nullFlavor"/>
                  <xsl:call-template name="dt-PQR-to-PQR">
                     <xsl:with-param name="in" select="hl7:translation"/>
                  </xsl:call-template>
               </xsl:element>
            </xsl:for-each>
            <xsl:if test="$in[hl7:center]">
               <xsl:element name="any" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="$in/hl7:center/@value|$in/hl7:center/@unit|$in/hl7:center/@nullFlavor"/>
                  <xsl:call-template name="dt-PQR-to-PQR">
                     <xsl:with-param name="in" select="$in/hl7:center/hl7:translation"/>
                  </xsl:call-template>
               </xsl:element>
            </xsl:if>
            <xsl:if test="$in[@value or hl7:translation]">
               <xsl:element name="any" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="$in/@value|$in/@unit|$in/@nullFlavor"/>
                  <xsl:call-template name="dt-PQR-to-PQR">
                     <xsl:with-param name="in" select="$in/hl7:translation"/>
                  </xsl:call-template>
               </xsl:element>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-IVL_INT-to-IVL_INT -->
<xsl:template name="dt-IVL_INT-to-IVL_INT">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-IVL-to-IVL">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-IVL_MO-to-IVL_MO -->
<xsl:template name="dt-IVL_MO-to-IVL_MO">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-IVL-to-IVL">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-IVL_PQ-to-IVL_PQ -->
<xsl:template name="dt-IVL_PQ-to-IVL_PQ">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-IVL-to-IVL">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-IVL_PQ-to-PQ -->
<xsl:template name="dt-IVL_PQ-to-PQ">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@unit|$in/@value"/>
            <xsl:copy-of select="$in/hl7:center/@value|$in/hl7:center/@unit|$in/hl7:center/@nullFlavor"/>
            <xsl:if test="$in/hl7:center/hl7:translation">
               <xsl:call-template name="dt-PQR-to-PQR">
                  <xsl:with-param name="in" select="$in/hl7:center/hl7:translation"/>
               </xsl:call-template>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-PQR-to-PQR -->
<xsl:template name="dt-PQR-to-PQR">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:for-each select="$in">
            <xsl:element name="{name()}" namespace="urn:hl7-org:v3">
               <xsl:copy-of select="@code|@codeSystem|codeSystemName|@codeSystemVersion|@nullFlavor|@value"/>
               <xsl:if test="self::node()[@displayName]">
                  <xsl:element name="displayName" namespace="urn:hl7-org:v3">
                     <xsl:attribute name="value" select="@displayName"/>
                  </xsl:element>
               </xsl:if>
               <xsl:call-template name="dt-ED-to-ED">
                  <xsl:with-param name="in" select="hl7:originalText"/>
               </xsl:call-template>
            </xsl:element>
         </xsl:for-each>
      </xsl:if>
   </xsl:template>
   <!-- dt-IVL_REAL-to-IVL_REAL -->
<xsl:template name="dt-IVL_REAL-to-IVL_REAL">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-IVL-to-IVL">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-IVL_TS-to-IVL_TS -->
<xsl:template name="dt-IVL_TS-to-IVL_TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:param name="dt"/>
      <xsl:call-template name="dt-IVL-to-IVL">
         <xsl:with-param name="in" select="$in"/>
         <xsl:with-param name="nm" select="$nm"/>
         <xsl:with-param name="dt" select="$dt"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-IVL_TS-to-QSET_TS -->
<xsl:template name="dt-IVL_TS-to-QSET_TS">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor"/>
            <xsl:attribute name="xsi:type" select="'IVL_TS'"/>
            <xsl:if test="$in/hl7:low/@inclusive">
               <xsl:attribute name="lowClosed" select="$in/hl7:low/@inclusive"/>
            </xsl:if>
            <xsl:if test="$in/hl7:high/@inclusive">
               <xsl:attribute name="highClosed" select="$in/hl7:high/@inclusive"/>
            </xsl:if>
            <xsl:for-each select="$in/hl7:low|$in/hl7:high|$in/width">
               <xsl:element name="{name()}" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="@* except @inclusive"/>
               </xsl:element>
            </xsl:for-each>
            <xsl:if test="$in[hl7:center]">
               <xsl:element name="any" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="$in/hl7:center/@value|$in/hl7:center/@nullFlavor"/>
               </xsl:element>
            </xsl:if>
            <xsl:if test="$in[@value]">
               <xsl:element name="any" namespace="urn:hl7-org:v3">
                  <xsl:attribute name="value" select="$in/@value"/>
               </xsl:element>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-MO-to-MO -->
<xsl:template name="dt-MO-to-MO">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-ON-to-ON -->
<xsl:template name="dt-ON-to-ON">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-EN-to-EN">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-ON-to-DSET_EN -->
<xsl:template name="dt-ON-to-DSET_EN">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-EN-to-DSET_EN">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-ON-to-EN -->
<xsl:template name="dt-ON-to-EN">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-EN-to-EN">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-PIVL_TS-to-PIVL_TS -->
<xsl:template name="dt-PIVL_TS-to-PIVL_TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{if (string-length($nm)&gt;0) then ($nm) else (name($in))}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
               <xsl:with-param name="in" select="$in/hl7:phase"/>
            </xsl:call-template>
            <xsl:call-template name="dt-PQ-to-PQ">
               <xsl:with-param name="in" select="$in/hl7:period"/>
            </xsl:call-template>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-PN-to-PN -->
<xsl:template name="dt-PN-to-PN">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-EN-to-EN">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-PN-to-DSET_EN -->
<xsl:template name="dt-PN-to-DSET_EN">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-EN-to-DSET_EN">
         <xsl:with-param name="in" select="$in"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-PQ-to-PQ -->
<xsl:template name="dt-PQ-to-PQ">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-REAL-to-REAL -->
<xsl:template name="dt-REAL-to-REAL">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-RTO_PQ_PQ-to-RTO_PQ_PQ -->
<xsl:template name="dt-RTO_PQ_PQ-to-RTO_PQ_PQ">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:attribute name="xsi:type" select="'RTO'"/>
            <xsl:for-each select="$in/hl7:numerator|$in/hl7:denominator">
               <xsl:element name="{name()}" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="@*"/>
                  <xsl:attribute name="xsi:type" select="'PQ'"/>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-RTO_PQ_PQ-to-DSET_RTO -->
<xsl:template name="dt-RTO_PQ_PQ-to-DSET_RTO">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@xsi:type"/>
            <xsl:for-each select="$in">
               <item xmlns="urn:hl7-org:v3">
                  <xsl:copy-of select="@*"/>
                  <xsl:for-each select="hl7:numerator|hl7:denominator">
                     <xsl:element name="{name()}" namespace="urn:hl7-org:v3">
                        <xsl:attribute name="xsi:type" select="'PQ'"/>
                        <xsl:copy-of select="@*"/>
                     </xsl:element>
                  </xsl:for-each>
               </item>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-SC-to-SC -->
<xsl:template name="dt-SC-to-SC">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@language|$in/@xsi:type"/>
            <xsl:if test="$in/text()[string-length(.)&gt;0]">
               <xsl:attribute name="value" select="$in/text()"/>
            </xsl:if>
            <xsl:if test="count($in/@displayName|$in/@code)&gt;0">
               <xsl:element name="code" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="$in/@code|$in/@codeSystem|$in/@codeSystemName|$in/@codeSystemVersion"/>
                  <xsl:if test="$in[@displayName]">
                     <xsl:element name="displayName" namespace="urn:hl7-org:v3">
                        <xsl:attribute name="value" select="$in/@displayName"/>
                     </xsl:element>
                  </xsl:if>
               </xsl:element>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-ST-to-ST -->
<xsl:template name="dt-ST-to-ST">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:attribute name="value" select="$in/text()"/>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-SXCM_TS-to-SXCM_TS -->
<xsl:template name="dt-SXCM_TS-to-SXCM_TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:if test="not(empty($in))">
         <xsl:choose>
            <xsl:when test="$in/@xsi:type='IVL_TS'">
               <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="nm" select="$nm"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='PIVL_TS'">
               <xsl:call-template name="dt-PIVL_TS-to-PIVL_TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="nm" select="$nm"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='EIVL_TS'">
               <xsl:call-template name="dt-EIVL_TS-to-EIVL_TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="nm" select="$nm"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in/@xsi:type='TS'">
               <xsl:call-template name="dt-TS-to-TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="nm" select="$nm"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="not($in/@xsi:type)">
               <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="nm" select="$nm"/>
                  <xsl:with-param name="dt" select="'IVL_TS'"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
               <xsl:message terminate="yes"> ERROR Found unsupported datatype '<xsl:value-of select="$in/@xsi:type"/>' in <xsl:value-of select="$in[1]/name()"/>
               </xsl:message>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:if>
   </xsl:template>
   <!-- dt-SXCM_TS-to-IVL_TS -->
<xsl:template name="dt-SXCM_TS-to-IVL_TS">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:choose>
            <xsl:when test="$in/@xsi:type='IVL_TS'">
               <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
                  <xsl:with-param name="in" select="$in"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:when test="$in[not(@xsi:type)]">
               <xsl:call-template name="dt-IVL_TS-to-IVL_TS">
                  <xsl:with-param name="in" select="$in"/>
                  <xsl:with-param name="dt" select="IVL_TS"/>
               </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
               <xsl:message terminate="yes"> ERROR Found unsupported datatype '<xsl:value-of select="$in/@xsi:type"/>' in <xsl:value-of select="$in[1]/name()"/>
               </xsl:message>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:if>
   </xsl:template>
   <!-- dt-SXCM_TS-to-QSET_TS -->
<xsl:template name="dt-SXCM_TS-to-QSET_TS">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:attribute name="xsi:type" select="'QSI_TS'"/>
            <xsl:for-each select="$in">
               <xsl:call-template name="dt-SXCM_TS-to-SXCM_TS">
                  <xsl:with-param name="in" select="."/>
                  <xsl:with-param name="nm" select="'term'"/>
               </xsl:call-template>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-StrucDoc.Text-to-ED -->
<xsl:template name="dt-StrucDoc.Text-to-ED">
      <xsl:param name="in"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in)}" namespace="urn:hl7-org:v3"><!-- TODO: @ID and @styleCode seem no longer supported in ED... missing anything without them? --><xsl:copy-of select="$in/@mediaType|$in/@language"/>
            <!-- TODO: copying any text content into text/xml regardless. Need more intelligent copying? --><xsl:element name="xml" namespace="urn:hl7-org:v3">
               <xsl:copy-of select="$in/node()"/>
            </xsl:element>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-TEL-to-TEL -->
<xsl:template name="dt-TEL-to-TEL">
      <xsl:param name="in"/>
      <xsl:copy-of select="$in/self::*"/>
   </xsl:template>
   <!-- dt-TEL-to-COLL_TEL -->
<xsl:template name="dt-TEL-to-COLL_TEL">
      <xsl:param name="in"/>
      <xsl:call-template name="dt-TEL-to-DSET_TEL">
         <xsl:with-param name="in" select="$in"/>
         <xsl:with-param name="dt" select="'DSET_AD'"/>
      </xsl:call-template>
   </xsl:template>
   <!-- dt-TEL-to-DSET_TEL -->
<xsl:template name="dt-TEL-to-DSET_TEL">
      <xsl:param name="in"/>
      <xsl:param name="dt"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{name($in[1])}" namespace="urn:hl7-org:v3">
            <xsl:if test="$in[1]/@xsi:type or string-length($dt)&gt;0">
               <xsl:attribute name="xsi:type" select="'DSET_TEL'"/>
            </xsl:if>
            <xsl:for-each select="$in">
               <xsl:element name="item" namespace="urn:hl7-org:v3">
                  <xsl:copy-of select="@use|@value|@nullFlavor"/>
               </xsl:element>
            </xsl:for-each>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-TS-to-TS -->
<xsl:template name="dt-TS-to-TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:param name="dt"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{if (string-length($nm)&gt;0) then ($nm) else (name($in))}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@value|$in/@nullFlavor|$in/@xsi:type"/>
            <xsl:if test="string-length($dt)&gt;0">
               <xsl:attribute name="xsi:type" select="$dt"/>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- dt-TS-to-IVL_TS -->
<xsl:template name="dt-TS-to-IVL_TS">
      <xsl:param name="in"/>
      <xsl:param name="nm"/>
      <xsl:param name="dt"/>
      <xsl:if test="not(empty($in))">
         <xsl:element name="{if (string-length($nm)&gt;0) then ($nm) else (name($in))}"
                      namespace="urn:hl7-org:v3">
            <xsl:copy-of select="$in/@nullFlavor"/>
            <xsl:if test="string-length($dt)&gt;0">
               <xsl:attribute name="xsi:type" select="$dt"/>
            </xsl:if>
            <xsl:if test="$in[@value]">
               <xsl:element name="any" namespace="urn:hl7-org:v3">
                  <xsl:attribute name="value" select="$in/@value"/>
               </xsl:element>
            </xsl:if>
         </xsl:element>
      </xsl:if>
   </xsl:template>
   <!-- processing-instruction()|comment()|text() -->
<xsl:template match="processing-instruction()|comment()|text()">
      <xsl:copy-of select="self::node()"/>
   </xsl:template>
   <!-- copy any other node as-is -->
<xsl:template match="*">
      <xsl:copy-of select="self::node()"/>
   </xsl:template>
</xsl:stylesheet>
